# Generated by Django 3.0.14 on 2022-04-12 22:47

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0314_punktacja_zrodla_kwarty"),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql(
                "0315_aktualna_jednostka_ostatnia_przypisana"
            )
        )
    ]
