# -*- coding: utf-8 -*-


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0041_auto_20160722_2230'),
        ('bpp', '0046_ostatnia_jednostka_trigger'),
    ]

    operations = [
    ]
