# Generated by Django 3.2.15 on 2022-08-15 15:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("zglos_publikacje", "0005_auto_20220807_2329"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="zgloszenie_publikacji",
            name="dostep_dnia",
        ),
        migrations.RemoveField(
            model_name="zgloszenie_publikacji",
            name="public_dostep_dnia",
        ),
        migrations.RemoveField(
            model_name="zgloszenie_publikacji",
            name="public_www",
        ),
        migrations.RemoveField(
            model_name="zgloszenie_publikacji",
            name="www",
        ),
        migrations.AddField(
            model_name="zgloszenie_publikacji",
            name="plik",
            field=models.FileField(
                blank=True,
                help_text="Jeżeli zgłaszana publikacja nie jest dostępna nigdzie w sieci internet,\n  "
                "      prosimy o dodanie załącznika",
                null=True,
                upload_to="",
                verbose_name="Plik załącznika",
            ),
        ),
        migrations.AddField(
            model_name="zgloszenie_publikacji",
            name="strona_www",
            field=models.URLField(
                blank=True,
                help_text="Pole opcjonalne. Adres URL lokalizacji pełnego tekstu pracy (dostęp otwarty lub nie). "
                "Jeżeli praca posiada numer DOI, wpisz go w postaci adresu URL czyli https://dx.doi.org/"
                "[NUMER_DOI]. Jeżeli praca nie posiada numeru DOI bądź nie jest dostępna w sieci, pozostaw "
                "to pole puste. ",
                max_length=1024,
                null=True,
                verbose_name="Dostępna w sieci pod adresem",
            ),
        ),
        migrations.AlterField(
            model_name="zgloszenie_publikacji",
            name="status",
            field=models.PositiveSmallIntegerField(
                choices=[
                    (0, "nowe zgłoszenie"),
                    (1, "zaakceptowane - dodane do bazy BPP"),
                    (2, "wymaga zmian - odesłano do zgłaszającego"),
                    (3, "odrzucono w całości"),
                    (4, "spam"),
                ],
                default=0,
            ),
        ),
        migrations.DeleteModel(
            name="Zgloszenie_Publikacji_Plik",
        ),
    ]
