# Generated by Django 3.0.14 on 2021-05-19 00:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0267_auto_20210519_0237"),
    ]

    operations = [
        migrations.AlterField(
            model_name="uczelnia",
            name="pbn_aktualizuj_na_biezaco",
            field=models.BooleanField(
                default=False,
                help_text="Aktualizuj rekordy w PBN przy zapisie rekordu, gdy redaktor kliknie odpowiedni przycisk.\n        Wybranie tej opcji spowoduje, ze na podstronach modułu redagowania dla wydawnictw pojawią się\n        przyciski 'Zapisz i wyślij do PBN'. ",
                verbose_name="Włącz opcjonalną aktualizację przy edycji",
            ),
        ),
    ]
