# Generated by Django 3.2.15 on 2022-09-20 10:28

from django.db import migrations, models

import bpp.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="CrossrefAPICache",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "doi",
                    bpp.fields.DOIField(
                        help_text="Digital Object Identifier (DOI)",
                        max_length=2048,
                        unique=True,
                    ),
                ),
                ("data", models.JSONField()),
                ("ostatnio_zmodyfikowany", models.DateTimeField(auto_now=True)),
            ],
        ),
    ]
