# -*- coding: utf-8 -*-
# Generated by Django 1.11.8 on 2018-02-21 22:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0117_auto_20180221_2327'),
    ]

    operations = [
        migrations.AlterField(
            model_name='typ_odpowiedzialnosci',
            name='typ_ogolny',
            field=models.SmallIntegerField(choices=[(0, 'autor'), (1, 'redaktor'), (2, 'inny'), (3, 'tłumacz'), (4, 'komentator'), (5, 'recenzent'), (6, 'opracował')], db_index=True, default=0, help_text='Pole to jest używane celem rozróżniania typu odpowiedzialności\n        na cele eksportu do PBN (autor i redaktor) oraz może być też wykorzystywane\n        np. w raportach autorów i jednostek. \n        ', verbose_name='Ogólny typ odpowiedzialności'),
        ),
    ]
