{% load i18n %}{% autoescape off %}
<p>
{% blocktrans %}You're receiving this email because you requested a password reset for your user account at {{ site_name }}.{% endblocktrans %}
</p>
<p>
{% trans "Please go to the following page and choose a new password:" %}
</p>
<p>
{% block reset_link %}
{{ protocol }}://{{ domain }}{% url 'password_reset_confirm' uid timestamp signature %}
{% endblock %}
</p>
<p>
{% trans "Your username, in case you've forgotten:" %} {{ user.get_username }}
</p>
<p>
{% trans "Thanks for using our site!" %}
</p>
{% blocktrans %}The {{ site_name }} team{% endblocktrans %}

{% endautoescape %}
