# Generated by Django 2.1.7 on 2019-03-27 21:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('import_dyscyplin', '0016_auto_20190327_0129'),
    ]

    operations = [
        migrations.AlterField(
            model_name='kolumna',
            name='rodzaj_pola',
            field=models.CharField(choices=[('tytuł', 'tytuł'), ('nazwisko', 'nazwisko'), ('imię', 'imię'), ('pesel', 'pesel'), ('orcid', 'orcid'), ('nazwa jednostki', 'nazwa jednostki'), ('wydział', 'wydział'), ('dyscyplina', 'dyscyplina'), ('kod dyscypliny', 'kod dyscypliny'), ('procent dyscypliny', 'procent dyscypliny'), ('subdyscyplina', 'subdyscyplina'), ('kod subdyscypliny', 'kod subdyscypliny'), ('procent subdyscypliny', 'procent subdyscypliny'), ('pomiń', 'pomiń')], max_length=50),
        ),
    ]
