# Generated by Django 2.1.7 on 2019-06-26 22:06

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0159_auto_20190327_0028'),
    ]

    operations = [
        migrations.AddField(
            model_name='patent_autor',
            name='dyscyplina_naukowa',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='bpp.Dyscyplina_Naukowa'),
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle_autor',
            name='dyscyplina_naukowa',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='bpp.Dyscyplina_Naukowa'),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte_autor',
            name='dyscyplina_naukowa',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='bpp.Dyscyplina_Naukowa'),
        ),
        migrations.AlterField(
            model_name='charakter_formalny',
            name='charakter_pbn',
            field=models.ForeignKey(blank=True, default=None, help_text='Wartość wybrana w tym polu zostanie użyta jako zawartość tagu &lt;is>\n                                      w plikach eksportu do PBN', null=True, on_delete=django.db.models.deletion.CASCADE, to='bpp.Charakter_PBN', verbose_name='Charakter PBN'),
        ),
    ]
