# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-04-14 17:17
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0124_auto_20180414_1917'),
        ('import_dyscyplin', '0006_auto_20180414_1841'),
    ]

    operations = [
        migrations.AddField(
            model_name='import_dyscyplin_row',
            name='dyscyplina_naukowa',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='bpp.Dyscyplina_Naukowa'),
        ),
        migrations.AddField(
            model_name='import_dyscyplin_row',
            name='subdyscyplina_naukowa',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='bpp.Dyscyplina_Naukowa'),
        ),
        migrations.AlterField(
            model_name='import_dyscyplin_row',
            name='stan',
            field=models.CharField(choices=[('nowy', 'nowy'), ('błędny', 'błędny'), ('zintegrowany', 'zintegrowany')], db_index=True, default='nowy', max_length=50),
        ),
    ]
