{% extends "base.html" %}

{% block extratitle %}
    {{ zrodlo.nazwa }}
{% endblock %}

{% block breadcrumbs %}
    {{ block.super }}
    <li><a href="{% url "bpp:browse_zrodla" %}">Źródła</a></li>
    <li class="current">{{ zrodlo.nazwa }}</li>
{% endblock %}

{% block content %}
    <h1>{{ zrodlo.nazwa }}</h1>
    {% include "browse/go_to_admin_change.html" with url="admin:bpp_zrodlo_change" pk=zrodlo.pk group="wprowadzanie danych" %}
    {% include "browse/go_to_admin_list.html" with url="admin:bpp_zrodlo_add" group="wprowadzanie danych" text="dodaj nowy rekord" %}
    {% if zrodlo.dyscyplina_zrodla_set.all %}
        Dyscypliny przypisane do źródła:
        <ul>
            {% for elem in zrodlo.dyscyplina_zrodla_set.all.select_related %}
                <li>{{ elem.dyscyplina }}</li>
            {% endfor %}</ul>
    {% endif %}
    {% if zrodlo.pbn_uid_id %}
        <p><a title="PBN UID: {{ zrodlo.pbn_uid_id }}" target="_blank" href="{{ uczelnia.pbn_api_root }}/core/#/journal/view/{{ zrodlo.pbn_uid_id }}/current">
            Kliknij, aby pokazać w PBN
        </a></p>
    {% endif %}
    <form method="post"
          action="{% url "bpp:browse_build_search" %}" class="browserForm">
        {% csrf_token %}
        <input type="hidden" name="suggested-title" value="{{ zrodlo }}"/>
        <input type="hidden" name="zrodlo" value="{{ zrodlo.pk }}"/>
        <p>
            Wyszukaj w tym źródle rekordy...
        </p>
        {% include "browse/w_latach.html" with prace_w_latach=zrodlo.prace_w_latach %}
        {% include "browse/tytul_raportu.html" with obj=zrodlo %}
        <input class="submit button" type="submit" value="Szukaj"/>
    </form>

{% endblock %}
