# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-04-17 11:33
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0130_clarivate_analytics'),
    ]

    operations = [
        migrations.AddField(
            model_name='praca_doktorska',
            name='liczba_cytowan',
            field=models.PositiveIntegerField(blank=True, null=True, verbose_name='Liczba cytowań'),
        ),
        migrations.AddField(
            model_name='praca_habilitacyjna',
            name='liczba_cytowan',
            field=models.PositiveIntegerField(blank=True, null=True, verbose_name='Liczba cytowań'),
        ),
    ]
