# Generated by Django 2.1.10 on 2019-10-27 10:41

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0186_auto_20191021_2008'),
    ]

    operations = [
        migrations.AddField(
            model_name='praca_doktorska',
            name='jezyk_alt',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='bpp.Jezyk', verbose_name='Język alternatywny'),
        ),
        migrations.AddField(
            model_name='praca_habilitacyjna',
            name='jezyk_alt',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='bpp.Jezyk', verbose_name='Język alternatywny'),
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='jezyk_alt',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='bpp.Jezyk', verbose_name='Język alternatywny'),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='jezyk_alt',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='bpp.Jezyk', verbose_name='Język alternatywny'),
        ),
    ]
