{% extends "base.html" %}

{% block content %}
    W systemie nie ma zdefiniowanych obiektów typu: Uczelnia. Zdefiniuj je za pomocą
    <a href="{% url "admin:index" %}">panelu administracyjnego</a>.
{% endblock %}