# Generated by Django 2.1.7 on 2019-09-10 20:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0179_auto_20190910_1416'),
        ('bpp', '0179_auto_20190910_2147'),
    ]

    operations = [
    ]
