# Generated by Django 3.0.14 on 2021-05-30 00:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0270_auto_20210530_0114"),
    ]

    operations = [
        migrations.AddField(
            model_name="patent_autor",
            name="profil_orcid",
            field=models.BooleanField(
                default=False,
                help_text="Zaznacz, jeżeli praca znajdje się na profilu ORCID autora",
                verbose_name="Praca w profilu ORCID autora",
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle_autor",
            name="profil_orcid",
            field=models.BooleanField(
                default=False,
                help_text="Zaznacz, jeżeli praca znajdje się na profilu ORCID autora",
                verbose_name="Praca w profilu ORCID autora",
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte_autor",
            name="profil_orcid",
            field=models.BooleanField(
                default=False,
                help_text="Zaznacz, jeżeli praca znajdje się na profilu ORCID autora",
                verbose_name="Praca w profilu ORCID autora",
            ),
        ),
        migrations.AlterField(
            model_name="autor",
            name="orcid_w_pbn",
            field=models.NullBooleanField(
                help_text="Jeżeli ORCID jest w bazie PBN, to pole powinno być zaznaczone. Zaznaczenie następuje\n        automatycznie, przez procedury integrujące bazę danych z PBNem w nocy. Można też zaznaczyć ręcznie.\n        Pole wykorzystywane jest gdy autor nie ma odpowiednika w PBN (pole 'PBN UID' rekordu autora jest puste,\n        zaś eksport danych powoduje komunikat zwrotny z PBN o nieistniejącym w ich bazie ORCID). W takich sytuacjach\n        należy w polu wybrać \"Nie\". ",
                verbose_name="ORCID jest w bazie PBN?",
            ),
        ),
    ]
