# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-04-15 09:07
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('import_dyscyplin', '0009_auto_20180415_0847'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='import_dyscyplin',
            options={'ordering': ('-modified',)},
        ),
        migrations.AlterField(
            model_name='import_dyscyplin_row',
            name='dyscyplina',
            field=models.CharField(db_index=True, max_length=200),
        ),
        migrations.AlterField(
            model_name='import_dyscyplin_row',
            name='kod_dyscypliny',
            field=models.CharField(db_index=True, max_length=20),
        ),
        migrations.AlterField(
            model_name='import_dyscyplin_row',
            name='kod_subdyscypliny',
            field=models.CharField(blank=True, db_index=True, max_length=20, null=True),
        ),
        migrations.AlterField(
            model_name='import_dyscyplin_row',
            name='subdyscyplina',
            field=models.CharField(blank=True, db_index=True, max_length=200, null=True),
        ),
    ]
