{% extends "django_tables2/table.html" %}

{% load i18n django_tables2 %}

{% block table.tfoot %}
    {% if table.rows %}
    <tr>
        <td colspan="{{  table.span_rows }}" align="right" style="text-align: right;">
            <strong>Suma:</strong>
        </td>
        {% if table.print_sum_impact %}
            <td>{{ table.sum_impact }}</td>
        {% endif %}
        <td>{{ table.sum_punkty_kbn }}</td>
    </tr>
    {% endif %}
{% endblock %}

{% block pagination %}
    {# bez paginacji - wyrzucamy całą tabelę #}
{% endblock %}
