# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-20 00:14
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0098_wybitnosc'),
    ]

    operations = [
        migrations.AddField(
            model_name='nagroda',
            name='nazwa',
            field=models.CharField(default='', max_length=200),
            preserve_default=False,
        ),
    ]
