# Generated by Django 2.1.7 on 2019-07-07 22:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0165_cache_punktacja_autora_cache_punktacja_dyscypliny_squashed_0167_auto_20190707_2029'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='cache_punktacja_autora',
            options={'ordering': ('autor__nazwisko', 'dyscyplina__nazwa')},
        ),
        migrations.AlterModelOptions(
            name='cache_punktacja_dyscypliny',
            options={'ordering': ('dyscyplina__nazwa',)},
        ),
    ]
