//.row{
//    @media #{$medium} {
//        max-width: 90em;
//    }
//}

.form-error {
  margin-top: 0 !important;
}

a:hover {
  text-decoration: underline;
}

ul.pagination a {
  text-decoration: none;
}

ul.pagination {
  margin-bottom: 0px;

}

label:hover {
  text-decoration: underline;
}

form.custom .custom.checkbox.checked:before {
  content: "\2714";
}

.small-table tbody tr td {
  font-size: 80%;
}

.small-table thead tr th {
  font-size: 70%;
}

.very-small-table tbody tr td {
  font-size: 60%;
}

.very-small-table thead tr th {
  font-size: 50%;
}

// test

@media print {
  a[href] {
    text-decoration: none;
  }

  a[href]:after {
    content: "" !important;
  }

  table {
    border: none;
    margin: 0pt;
  }

  //table tbody tr, td {
  //  page-break-inside: auto !important;
  //  page-break-after: avoid;
  //}
  //
  //table tr, td {
  //  page-break-before: avoid !important;
  //  page-break-inside: auto !important;
  //  page-break-after: avoid;
  //}

  table tfoot tr th,
  tfoot {
    display: table-row-group;
  }

  @page {
    margin-top: 1cm !important;
    margin-bottom: 1.5cm !important;
    margin-left: 0.5cm !important;
    margin-right: 1cm !important;
  }

  body, p, div {
    font-size: 9pt;
  }

  h1.bpp-multiseek-title {
    font-size: 12pt;
    font-weight: bold;
  }

}

.alert-box {
  font-weight: normal;
}

.alert-box a {
  color: white;
  font-weight: bold;
}

.navigation-autocomplete-icon {
  width: 1.8em;
  height: 1.8em;
}

#global-nav-table {
  border-top: none;
  border-bottom: none;
  border-left: none;
  border-right: none;
  padding: 0px;
  margin: 0px;
}

body ol li {
  list-style-type: decimal;
  margin-left: 2em;
}

.radioselect li {
  list-style-type: none;
}

.sub-nav {
  background-color: #f2f2f2;
  border-radius: 6px;
}

.nonfield-errors ol {
  margin: 0px;
}

.nonfield-errors ol li {
  list-style-type: none;
}

.multiseek-range-field-label {
  padding-left: 0.5em !important;
  padding-top: 0.5em !important;
}

@media print {
  div.grid-x {
    display: block !important;
  }

  tr, img {
    page-break-inside: auto !important;
  }

  table.kbntab tr td {
    page-break-inside: auto;
    page-break-after: avoid;
  }

  table.kbntab tr {
    page-break-inside: auto;
    page-break-after: avoid;
  }

  table.bpp-table tr td {
    page-break-inside: auto;
    page-break-after: avoid;
  }

  table.bpp-table tr {
    page-break-inside: auto;
    page-break-after: avoid;
  }

}

@media print {
  // patch dla django_tables2 screen.css, issue #409
  div.table-container {
    display: inline !important;
  }
}

////

.select2-container .select2-search--inline .select2-search__field {
  font-size: 102%;

}

.select2-container--default .select2-results__option--highlighted[aria-selected] {
  background-color: $primary-color !important;
}

.select2-container--foundation .select2-results > .select2-results__options {
  max-height: 400px !important;
}

::-ms-check {
  color: red;
  background: black;
  padding: 1em;
}

.bpp-lp-column {
  text-align: right;
}

table.bpp-table tbody tr td {
  vertical-align: top;
}

table.bpp-table tbody tr.even {
  background: white !important;
}

div.table-container ul.pagination {
}

//$topbar-background: rgb(192, 192, 192, 0.8);

.top-bar {
  z-index: 10 !important;
}

#CookielawBanner {
  margin-bottom: -10px !important;
}

.flash-on-notification {
}

// SPINNER

.spinner {
  margin: 0px auto 0;
  width: 70px;
  text-align: center;
}

.spinner > div {
  width: 18px;
  height: 18px;
  background-color: #333;

  border-radius: 100%;
  display: inline-block;
  -webkit-animation: sk-bouncedelay 1.4s infinite ease-in-out both;
  animation: sk-bouncedelay 1.4s infinite ease-in-out both;
}

.spinner .bounce1 {
  -webkit-animation-delay: -0.32s;
  animation-delay: -0.32s;
}

.spinner .bounce2 {
  -webkit-animation-delay: -0.16s;
  animation-delay: -0.16s;
}

@-webkit-keyframes sk-bouncedelay {
  0%, 80%, 100% {
    -webkit-transform: scale(0)
  }
  40% {
    -webkit-transform: scale(1.0)
  }
}

@keyframes sk-bouncedelay {
  0%, 80%, 100% {
    -webkit-transform: scale(0);
    transform: scale(0);
  }
  40% {
    -webkit-transform: scale(1.0);
    transform: scale(1.0);
  }
}

.dropdown.menu li a {
  background: none !important;
}

.szczegolyRekordu tr th {
  vertical-align: top;
  text-align: right;
}

.hidden {
  display: none;
}
