# Generated by Django 2.1.7 on 2019-03-19 15:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0155_CASCADE'),
    ]

    operations = [
        migrations.AddField(
            model_name='patent_autor',
            name='procent',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Udział w opracowaniu (procent)'),
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle_autor',
            name='procent',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Udział w opracowaniu (procent)'),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte_autor',
            name='procent',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Udział w opracowaniu (procent)'),
        ),
    ]
