# Generated by Django 2.1.7 on 2019-03-24 17:28

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0155_CASCADE'),
    ]

    operations = [
        migrations.AddField(
            model_name='autor_dyscyplina',
            name='procent_dyscypliny',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True),
        ),
        migrations.AddField(
            model_name='autor_dyscyplina',
            name='procent_subdyscypliny',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True),
        ),
        migrations.AddField(
            model_name='autor_dyscyplina',
            name='subdyscyplina',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='subdyscyplina', to='bpp.Dyscyplina_Naukowa'),
        ),
        migrations.AlterField(
            model_name='autor_dyscyplina',
            name='dyscyplina',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='dyscyplina', to='bpp.Dyscyplina_Naukowa'),
        ),
    ]
