# Generated by Django 3.0.14 on 2021-10-27 21:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("ewaluacja2021", "0003_auto_20211027_2320"),
    ]

    operations = [
        migrations.AddField(
            model_name="importmaksymalnychslotow",
            name="ostatnia_zmiana",
            field=models.DateTimeField(auto_now=True),
        ),
    ]
