# Generated by Django 3.0.14 on 2021-09-15 19:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0292_przypinanie_dyscyplin"),
    ]

    operations = [
        migrations.AddField(
            model_name="uczelnia",
            name="pbn_api_kasuj_przed_wysylka",
            field=models.BooleanField(
                default=False,
                verbose_name="Kasuj oświadczenia rekordu przed wysłaniem do PBN",
            ),
        ),
        migrations.AddField(
            model_name="uczelnia",
            name="pbn_api_nie_wysylaj_prac_bez_pk",
            field=models.BooleanField(
                default=False, verbose_name="Nie wysyłaj do PBN prac z PK=0"
            ),
        ),
    ]
