/* hide action input fields */
#changelist-form-step, #changelist-form-page {
	display: none;
	margin-left: 0.5em;
}

/* styles for list view */
#result_list thead th.column-_reorder {
	width: 50px;
}

#result_list div.drag {
	background: url(../icons/drag.png) repeat 0px 0px;
	cursor: pointer;
}
/* styles for tabular inlines */
div.inline-group table.ui-sortable tr.form-row.has_original td.drag {
	cursor: pointer;
	background-image: url(../icons/drag.png);
	background-repeat: repeat;
	width: 20px;
}
div.inline-group table.ui-sortable tr.form-row.has_original td.original p {
	left: initial;
}

div.inline-group table.ui-sortable tr.form-row td.is_hidden {
	display: none;
}
/* styles for stacked inlines */
div.inline-group.ui-sortable div.inline-related.has_original h3 {
	background: url(../icons/drag.png) repeat;
}
div.inline-group.ui-sortable div.inline-related.has_original h3:hover {
	cursor: pointer;
}
div.inline-group.ui-sortable div.form-row.is_hidden {
	display: none;
}
