# Generated by Django 2.1.10 on 2019-10-21 18:08

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0185_auto_20191021_2008'),
    ]

    operations = [
        migrations.AlterField(
            model_name='autor',
            name='orcid',
            field=models.CharField(blank=True, db_index=True, help_text='Open Researcher and Contributor ID, vide http://www.orcid.org', max_length=19, null=True, unique=True, validators=[django.core.validators.RegexValidator(code='orcid_invalid_format', message='Identyfikator ORCID to 4 grupy po 4 cyfry w każdej, oddzielone myślnikami', regex='^\\d\\d\\d\\d-\\d\\d\\d\\d-\\d\\d\\d\\d-\\d\\d\\d(\\d|X)$')], verbose_name='Identyfikator ORCID'),
        ),
    ]
