# Generated by Django 2.1.7 on 2019-09-02 23:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0176_auto_20190903_0108'),
    ]

    operations = [
        migrations.CreateModel(
            name='Cache_Punktacja_Autora_Query',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('pkdaut', models.DecimalField(decimal_places=4, max_digits=20)),
                ('slot', models.DecimalField(decimal_places=4, max_digits=20)),
            ],
            options={
                'db_table': 'cache_punktacja_autora',
                'managed': False,
            },
        ),
    ]
