#CookielawBanner {
    background: #fff;
    padding: 15px 0;
}

#CookielawBanner .container {
    position: relative;
}

#CookielawBanner #CookielawCross {
    background: url('../img/close.png') no-repeat 0 0;
    cursor: pointer;
    display: block;
    position: absolute;
    top: 0;
    right: 0;
    width: 15px;
    height: 15px;
}
