{% extends "base.html" %}

{% load columns %}

{% block breadcrumbs %}
    {{ block.super }}
    <li {% if wybrana == None %}class="current"{% endif %}>
        {% if wybrana != None %}<a href="{% url "bpp:browse_zrodla" %}">{% endif %}
        Źródła
        {% if wybrana != None %}</a>{% endif %}
    </li>
    {% if wybrana != None %}
        <li class="current">Litera {{ wybrana }}</a>
    {% endif %}
{% endblock %}

{% block extratitle %}
    Indeks źródeł{% if wybrana != None %} - litera {{ wybrana }}{% endif %}
{% endblock %}

{% block content %}
    {% url "bpp:browse_zrodla" as browse_zrodla %}
    {% include "browse/literki.html" with pierwszy_tab="wszystkie" url=browse_zrodla %}
    {% include "browse/go_to_admin_list.html" with url="admin:bpp_zrodlo_changelist" group="wprowadzanie danych" text="<i class='fi-wrench'></i> wyświetl w module redagowania" %}

    {% url "bpp:browse_zrodlo" as browse_zrodlo %}

    <div class="grid-x grid-margin-x hide-for-print" style="text-align: right;">
        <div class="large-4 medium-4 cell">
            {% include "browse/search_form.html" with url=browse_zrodla tekst="Wpisz część nazwy i wciśnij ENTER..." name="search" flt=flt %}
        </div>
        <div class="large-8 medium-8 cell">
            {% include "pagination.html" %}

        </div>
    </div>

    <div class="grid-x grid-margin-x">
        {% for col in object_list|columns:2 %}
            <div class="large-6 cell">
                <ul class="no-bullet">
                    {% for item in col %}
                        <li><a href="{% url "bpp:browse_zrodlo" item.slug %}">{{ item }}</a></li>
                    {% endfor %}
                </ul>
            </div>
        {% endfor %}
        {% if not object_list %}
            <div class="callout warning cell">
                Nie znaleziono takich źródeł. <p></p>
                <a href=".">Kliknij tutaj, aby spróbować ponownie.</a>
            </div>

        {% endif %}
    </div><!-- /row -->


{% endblock %}