{% load compress %}<!DOCTYPE html>
{#PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"#}
{#        "http://www.w3.org/TR/html4/loose.dtd">#}
<html class="no-js" lang="pl" dir="ltr">
<head>
    <meta http-equiv="X-UA-Compatible" content="IE=10">
    {% load static %}
    {% load compress %}
    <title>{% if "test" in request.get_host %}** SERWER TESTOWY ** {% endif %}{% block title %}{% block extratitle %}{% endblock %}
        - Bibliografia Publikacji {{ uczelnia.skrot }}
    {% endblock %}</title>
    <meta charset="utf-8"/>
    <meta name="viewport" content="width=device-width"/>

    {% load i18n %}
    <script type="text/javascript" src="/bpp/jsi18n/?language={{ LANGUAGE_CODE }}"></script>

    {#        bare.html #}
    {% compress css %}
        {#        base.html #}
        <link rel="stylesheet" type="text/css" href="{% static THEME_NAME %}"/>
        <link rel="stylesheet" type="text/css" href="{% static "jqueryui/jquery-ui.css" %}">
        <link rel="stylesheet" type="text/css" href="{% static "multiseek/css/style.css" %}">
        <link rel="stylesheet" type="text/css" href="{% static 'session_security/style.css' %}">
        <link rel="stylesheet" type="text/css"
              href="{% static "foundation-datepicker/foundation/fonts/foundation-icons.css" %}">
        <link rel="stylesheet" type="text/css"
              href="{% static "foundation-datepicker/css/foundation-datepicker.min.css" %}">
        <link rel="stylesheet" type="text/css" href="{% static "select2/dist/css/select2.min.css" %}">
        <link rel="stylesheet" type="text/css" href="{% static "autocomplete_light/select2.css" %}">
        <link rel="stylesheet" type="text/css"
              href="{% static "select2-foundation_theme/dist/select2-foundation-theme.css" %}">

        <link rel="stylesheet" href="{% static "multiseek/css/style.css" %}"/>

{#        <link rel="stylesheet" href="{% static "datatables.net-dt/css/jquery.dataTables.css" %}"/>#}
        <link rel="stylesheet" href="{% static "datatables.net-zf/css/dataTables.foundation.css" %}"/>


    {% endcompress %}

    {% compress js %}
        {#        bare.html #}

        <script src="{% static 'jquery/dist/jquery.min.js' %}"></script>
        <script src="{% static "what-input/dist/what-input.js" %}"></script>
        <script src="{% static 'foundation-sites/dist/js/foundation.min.js' %}"></script>

        <script src="{% static "jquery.cookie/jquery.cookie.js" %}"></script>

        {#        base.html #}

        <script src="{% static 'cookielaw/js/cookielaw.js' %}"></script>

        <script src="{% static 'jqueryui/jquery-ui.min.js' %}"></script>

        <script src="{% static "multiseek/js/multiseek.js" %}" type="text/javascript"></script>

        <script type="text/javascript" src="{% static "bpp/js/bpp.js" %}"></script>

        <script src="{% static "notifications/js/mustache.js" %}"></script>
        <script src="{% static "notifications/js/notifications.js" %}"></script>

        <script src="{% static "foundation-datepicker/js/foundation-datepicker.min.js" %}"></script>
        <script src="{% static "foundation-datepicker/js/locales/foundation-datepicker.pl.js" %}"></script>

        <script src="{% static "datatables.net/js/jquery.dataTables.js" %}"></script>
        <script src="{% static "datatables.net-zf/js/dataTables.foundation.js" %}"></script>
        {% block extrahead_js %}
        {% endblock %}

        <script src="{% static 'jinplace/js/jinplace.js' %}"></script>

        <script type="text/javascript" src="{% static 'session_security/script.js' %}"></script>

        <script src="{% static "select2/dist/js/select2.full.min.js" %}"></script>
        <script src="{% static "select2/dist/js/i18n/pl.js" %}"></script>
        <script src="{% static "autocomplete_light/autocomplete_light.js" %}"></script>
        <script src="{% static "autocomplete_light/i18n/pl.js" %}"></script>
        <script src="{% static "autocomplete_light/select2.js" %}"></script>


    {% endcompress %}

    {% block extrahead %}
    {% endblock %}
    {% load cache %}
    {% cache 3600 favicon %}
        {% load favtags %}
        {% placeFavicon %}
    {% endcache %}
</head>
<body style="display: none;">
{% block body %}
{% endblock %}
<script type="text/javascript">
    $(document).foundation();
    $.fn.select2.defaults.set('language', 'pl');
    $.fn.select2.defaults.set('theme', 'foundation');

    $(document).on('select2:open', () => {
        function _(){
            document.querySelector('.select2-search__field').focus()
        }

        setTimeout(_, 10);
    });

    $.extend(true, $.fn.dataTable.defaults, {
        // Przetłumacz wszystkie tabelki DataTables
        "language": {
            "url": "{% static "bpp/js/Polish.json" %}"
        },
        "lengthMenu": [ [10, 25, 50, 100, -1], [10, 25, 50, 100, "wszystkie"] ]
    });


</script>
</body>
<footer>
    {% load bpp_version %}
    <!-- wygenerowano dnia {% bpp_localtime %}, wersja {% bpp_version %} -->
</footer>

<!-----Flash of Unstyled Content---------->
<script>
    document.getElementsByTagName("body")[0].style.display = '';
</script>
<noscript>
    <style>body {
        display: block !important;
    }</style>
</noscript>
<!-----Flash of Unstyled Content---------->

</html>
