# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-06-24 16:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0140_auto_20180624_1620'),
    ]

    operations = [
        migrations.AddField(
            model_name='konferencja',
            name='typ_konferencji',
            field=models.SmallIntegerField(blank=True, choices=[(1, '🚆 krajowa'), (2, '✈️ międzynarodowa'), (3, '🚲 lokalna')], null=True),
        ),
    ]
