# Generated by Django 2.1.7 on 2019-03-24 17:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0156_auto_20190324_1828'),
    ]

    operations = [
        migrations.RenameField(
            model_name='autor_dyscyplina',
            old_name='dyscyplina',
            new_name='dyscyplina_naukowa',
        ),
        migrations.RenameField(
            model_name='autor_dyscyplina',
            old_name='subdyscyplina',
            new_name='subdyscyplina_naukowa',
        ),
    ]
