# -*- coding: utf-8 -*-


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0038_autor_pesel_md5'),
        ('bpp', '0039_wydzial_archiwalny'),
    ]

    operations = [
    ]
