# Generated by Django 2.1.7 on 2019-09-02 23:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0175_merge_20190824_0948'),
    ]

    operations = [
        migrations.AlterField(
            model_name='charakter_formalny',
            name='charakter_sloty',
            field=models.PositiveSmallIntegerField(blank=True, choices=[(1, 'Książka'), (2, 'Rozdział')], default=None, help_text='Jak potraktować ten charakter przy kalkulacji slotów dla wydawnictwa zwartego?', null=True, verbose_name='Charakter dla slotów'),
        ),
    ]
