# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-19 22:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0094_seria_wydawnicza'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='seria_wydawnicza',
            options={'verbose_name': 'seria wydawnicza', 'verbose_name_plural': 'serie wydawnicze'},
        ),
        migrations.RemoveField(
            model_name='seria_wydawnicza',
            name='e_issn',
        ),
        migrations.RemoveField(
            model_name='seria_wydawnicza',
            name='issn',
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='e_issn',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='e-ISSN'),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='issn',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='ISSN'),
        ),
    ]
