# Generated by Django 3.0.14 on 2021-10-10 20:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0303_denorm_cleanup_cachequeue_gone"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="autor_dyscyplina",
            options={
                "verbose_name": "powiązanie autor-dyscyplina",
                "verbose_name_plural": "powiązania autor-dyscyplina",
            },
        ),
        migrations.AlterModelOptions(
            name="szablondlaopisubibliograficznego",
            options={
                "verbose_name": "powiązanie szablonu dla opisu bibliograficznego",
                "verbose_name_plural": "powiązania szablonów dla opisu bibliograficznego",
            },
        ),
    ]
