# Generated by Django 3.0.7 on 2020-08-05 23:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0214_auto_20200628_2344"),
    ]

    operations = [
        migrations.AddField(
            model_name="autor_dyscyplina",
            name="rodzaj_autora",
            field=models.CharField(
                choices=[
                    (" ", "brak danych"),
                    ("N", "pracownik zaliczany do liczby N"),
                    ("D", "doktorant"),
                    ("Z", "inny zatrudniony"),
                ],
                default=" ",
                max_length=1,
            ),
        ),
        migrations.AddField(
            model_name="autor_dyscyplina",
            name="wymiar_etatu",
            field=models.DecimalField(
                blank=True, decimal_places=2, max_digits=3, null=True
            ),
        ),
        migrations.AlterField(
            model_name="charakter_formalny",
            name="charakter_ogolny",
            field=models.CharField(
                choices=[
                    ("art", "Artykuł"),
                    ("ksi", "Książka"),
                    ("roz", "Rozdział"),
                    ("xxx", "Inne"),
                ],
                default="xxx",
                help_text="Charakter ogólny uzywany jest m.in. do generowania opisów bibliograficznych. Stanowi on\n        ogólne określenie rekordu, czy jest to książka, rozdział czy coś innego. ",
                max_length=3,
            ),
        ),
    ]
