# Generated by Django 3.0.14 on 2021-10-27 22:39

from django.db import migrations, models

import ewaluacja2021.validators


class Migration(migrations.Migration):

    dependencies = [
        ("ewaluacja2021", "0004_importmaksymalnychslotow_ostatnia_zmiana"),
    ]

    operations = [
        migrations.AddField(
            model_name="importmaksymalnychslotow",
            name="started_on",
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="importmaksymalnychslotow",
            name="plik",
            field=models.FileField(
                upload_to="",
                validators=[
                    ewaluacja2021.validators.xlsx_header_validator(
                        columns=[
                            "Stopień / Tytuł",
                            "Nazwisko",
                            "Imię",
                            "ORCID",
                            "Dyscyplina",
                            "Uwzględniony w ewaluacji",
                            "maksymalna suma udziałów jednostkowych - wszystkie dyscypliny",
                            "maksymalna suma udziałów jednostkowych - monografie",
                        ],
                        max_header_row=100,
                    )
                ],
            ),
        ),
    ]
