# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-19 07:52
from __future__ import unicode_literals

import django.contrib.postgres.fields.hstore
from django.contrib.postgres.operations import HStoreExtension
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0088_orcid'),
    ]

    operations = [
        HStoreExtension(),

        migrations.AddField(
            model_name='patent',
            name='legacy_data',
            field=django.contrib.postgres.fields.hstore.HStoreField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='praca_doktorska',
            name='legacy_data',
            field=django.contrib.postgres.fields.hstore.HStoreField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='praca_habilitacyjna',
            name='legacy_data',
            field=django.contrib.postgres.fields.hstore.HStoreField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='legacy_data',
            field=django.contrib.postgres.fields.hstore.HStoreField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='legacy_data',
            field=django.contrib.postgres.fields.hstore.HStoreField(blank=True, null=True),
        ),
    ]
