# Generated by Django 2.1.7 on 2019-07-21 21:15

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0168_dyscyplina_w_autorzy_mat'),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0169_dyscyplina_change_trigger_cacher")
        ),
    ]
