# Generated by Django 3.0.11 on 2021-02-02 07:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0235_auto_20210125_0042"),
        ("bpp", "0235_auto_20210201_1305"),
    ]

    operations = []
