#grp-navigation {
    padding: 0px 0px !important;
}

#grp-navigation ul li {
    position: relative;
    list-style: none;
}

#grp-navigation ul li a {
    white-space: nowrap;
}

#grp-navigation #navigation-menu {
    height: 35px;
    z-index: 9999;
}

#grp-navigation #bookmark-button {
    cursor: pointer;
    float: right;
    top: auto;
    height: 25px;
    width: 24px;
    margin-top: 4px;
    margin-right: 10px;
    margin-left: 3px;
    border: none;
    text-indent: -5000px;
    overflow: hidden;
    background: transparent url(/static/admin_tools/images/admin-tools.png) no-repeat 0 -425px;
}

#grp-navigation #bookmark-button.bookmarked {
    background-position: 0 -445px;
}

#grp-navigation ul#navigation-menu li {
    float: left;
}

#grp-navigation ul#navigation-menu li a {
    display: block;
    text-decoration: none;
    font-weight: bold;
    padding: 9px 15px;
    /*border-right: 1px solid #ededed;*/
    border-right: 1px solid #090909;
    border-left: 1px solid #343434;

}

#grp-navigation ul#navigation-menu li.disabled a {
    color: #bbb;
    cursor: default;
}

#grp-navigation ul#navigation-menu li.first a {
    margin: 5px 0 0 12px;
    padding-top: 4px;
    text-indent: 14px;
    background: transparent url(/static/admin_tools/images/admin-tools.png) no-repeat 0 -385px;
    height: 12px;
}

#grp-navigation ul#navigation-menu li span {
    float: right;
    height: 10px;
    width: 20px;
    background: transparent url(/static/admin_tools/images/admin-tools.png) no-repeat 0 -360px;
}

#grp-navigation ul#navigation-menu li:hover,
#grp-navigation ul#navigation-menu li.over,
#grp-navigation ul#navigation-menu li.selected {

}

#grp-navigation ul#navigation-menu li ul {
    display: none;
    position: absolute;
    top: auto;
    left: auto;
    margin: 0;
    border-color: black !important;
    padding: 0px;
}

#grp-navigation ul#navigation-menu li ul li {
    padding: 0;
    float: none;

    background: none repeat scroll 0 0 #222222;
    border-bottom-left-radius: 3px;
    border-bottom-right-radius: 3px;
    border-top: 1px solid #090909;
    display: block;
    margin: -1px 0 0 -1px;
    z-index: 1010;
}

#grp-navigation ul#navigation-menu li ul li a {
    display: block;
    border-width: 0 1px 1px 1px;
    text-transform: none;
    min-width: 180px;
}

#grp-navigation ul#navigation-menu li ul li span {
    background-position: 0 -370px;
}

#grp-navigation ul#navigation-menu li ul li ul {
    left: 100%;
    top: 0;
    border-top: 1px solid #ededed;
}

#grp-navigation ul#navigation-menu li ul li ul li a {
    white-space: nowrap;
}

#grp-navigation ul#navigation-menu li:hover ul li ul,
#grp-navigation ul#navigation-menu li.over ul li ul {
    display: none;
}

#grp-navigation ul#navigation-menu li:hover ul,
#grp-navigation ul#navigation-menu li.over ul,
#grp-navigation ul#navigation-menu li ul li:hover ul,
#grp-navigation ul#navigation-menu li ul li.over ul {
    display: block;
}

#grp-navigation ul#navigation-menu li:hover ul li,
#grp-navigation ul#navigation-menu li.over ul li,
#grp-navigation ul#navigation-menu li ul li:hover ul li,
#grp-navigation ul#navigation-menu li ul li.over ul li {
}

#grp-navigation ul#navigation-menu li ul li:hover,
#grp-navigation ul#navigation-menu li ul li.over,
#grp-navigation ul#navigation-menu li ul li ul li:hover,
#grp-navigation ul#navigation-menu li ul li ul li.over {

}

#grp-navigation ul#navigation-menu li.disabled a:hover,
#grp-navigation ul#navigation-menu li.disabled a.over {
    background: none;
}

@media (max-width: 1100px) {
    #grp-navigation ul#navigation-menu li a {
        font-size: 7pt !important;
    }
}

@media (max-width: 1320px) {
    #grp-navigation ul#navigation-menu li a {
        display: block;
        text-decoration: none;
        font-weight: bold;
        padding: 9px 3px;
        font-size: 8pt;
        /*border-right: 1px solid #ededed;*/
        border-right: 1px solid #090909;
        border-left: 1px solid #343434;

    }

    #navigation_autocomplete {
        font-size: 6pt;

    }

    body {
        font-size: 0.8em;
    }

    header#grp-header #grp-navigation ul#grp-user-tools > li a {
        font-size: 9px;
        width: 50px;
    }

    yourlabs-autocomplete inner-container  id-navigation_autocomplete a {
        font-size: 6px;
    }
}


header#grp-header #grp-navigation ul#grp-user-tools > li a {
    float: right;
    margin-right: 5px;
}

header#grp-header #grp-navigation ul#grp-user-tools > li.grp-user-options-container:last-child {
    width: 100px;
}