# Generated by Django 3.0.14 on 2021-07-25 21:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0280_auto_20210725_2217"),
    ]

    operations = [
        migrations.AlterField(
            model_name="typ_odpowiedzialnosci",
            name="typ_ogolny",
            field=models.SmallIntegerField(
                choices=[
                    (0, "autor"),
                    (1, "redaktor"),
                    (2, "inny"),
                    (3, "tłumacz"),
                    (4, "komentator"),
                    (5, "recenzent"),
                    (6, "opracował"),
                    (7, "redaktor tłumaczenia"),
                ],
                db_index=True,
                default=0,
                help_text="Pole to jest używane celem rozróżniania typu odpowiedzialności\n        na cele eksportu do PBN (autor i redaktor) oraz może być też wykorzystywane\n        np. w raportach autorów i jednostek.\n        ",
                verbose_name="Ogólny typ odpowiedzialności",
            ),
        ),
    ]
