# Generated by Django 3.0.14 on 2021-08-20 13:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0288_rekord_mat_isbn"),
    ]

    operations = [
        migrations.AddField(
            model_name="patent_autor",
            name="data_oswiadczenia",
            field=models.DateField(
                blank=True,
                help_text="Informacja eksportowana do PBN, gdy uzupełniono",
                null=True,
                verbose_name="Data oświadczenia",
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle_autor",
            name="data_oswiadczenia",
            field=models.DateField(
                blank=True,
                help_text="Informacja eksportowana do PBN, gdy uzupełniono",
                null=True,
                verbose_name="Data oświadczenia",
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte_autor",
            name="data_oswiadczenia",
            field=models.DateField(
                blank=True,
                help_text="Informacja eksportowana do PBN, gdy uzupełniono",
                null=True,
                verbose_name="Data oświadczenia",
            ),
        ),
    ]
