# Generated by Django 2.1.10 on 2019-10-21 18:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0184_autor_expertus_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='autor',
            name='expertus_id',
            field=models.CharField(blank=True, db_index=True, max_length=10, null=True, unique=True, verbose_name='Identyfikator w bazie Expertus'),
        ),
    ]
