<div class="tabs hide-for-print" id="literki-tabs" style="margin-bottom: 10px;">

    <span class="tabs-title {% if wybrana == None %}is-active{% endif %}">
    <a style="padding: 1.18rem" href="{{ url }}" {% if wybrana == None %}aria-selected="true"{% endif %}>
        &hellip;
    </a>

    </span>

    {% for literka in literki %}
        <span class="tabs-title
        {% if literka == wybrana %}is-active{% endif %}
        ">
            <a style="padding: 1.18rem" {% if literka == wybrana %}class="wybrana" aria-selected="true"{% endif %}
               id="literka_{{ literka }}"
               href="{{ url }}{{ literka }}">{{ literka }}</a>
        </span>
    {% endfor %}
</div>


