# -*- coding: utf-8 -*-


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0064_autor_jednostka_aktualna'),
        ('bpp', '0051_auto_20161201_1137'),
    ]

    operations = [
    ]
