/*! Select2 4.1.0-rc.0 | https://github.com/select2/select2/blob/master/LICENSE.md */
var dalLoadLanguage=function(n){var t;(t=n&&n.fn&&n.fn.select2&&n.fn.select2.amd?n.fn.select2.amd:t).define("select2/i18n/is",[],function(){return{inputTooLong:function(n){var t=n.input.length-n.maximum,n="Vinsamlegast styttið texta um "+t+" staf";return t<=1?n:n+"i"},inputTooShort:function(n){var t=n.minimum-n.input.length,n="Vinsamlegast skrifið "+t+" staf";return 1<t&&(n+="i"),n+" í viðbót"},loadingMore:function(){return"Sæki fleiri niðurstöður…"},maximumSelected:function(n){return"Þú getur aðeins valið "+n.maximum+" atriði"},noResults:function(){return"Ekkert fannst"},searching:function(){return"Leita…"},removeAllItems:function(){return"Fjarlægðu öll atriði"}}}),t.define,t.require},event=new CustomEvent("dal-language-loaded",{lang:"is"});document.dispatchEvent(event);