# Generated by Django 3.0.14 on 2022-05-03 20:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0317_uczelnia_pokaz_tylko_nadrzedne"),
    ]

    operations = [
        migrations.AddConstraint(
            model_name="autor_jednostka",
            constraint=models.UniqueConstraint(
                condition=models.Q(podstawowe_miejsce_pracy=True),
                fields=("autor_id",),
                name="jedno_podstawowe_miejsce_pracy_na_autora",
            ),
        ),
    ]
