{% extends "admin/change_form.html" %}

{% block object-tools-items %}
    {% if original.pbn_uid_id %}
        <li><a target="_blank" href="{{ original.pbn_uid.link_do_pbn }}">Zobacz w PBN</a></li>
        <li><a target="_blank" href="/admin/pbn_api/publication/{{ original.pbn_uid_id }}/change">Lokalny PBN</a></li>
    {% endif %}
    {% if original.wydawnictwo_nadrzedne_id %}
        <li><a target="_blank" href="{% url "admin:bpp_wydawnictwo_zwarte_change" original.wydawnictwo_nadrzedne_id %}">Nadrzędne</a></li>
    {% endif %}
    {% if original.wydawnictwa_powiazane_set.exists %}
        <li><a target="_blank" href="../../?q-l=on&q=wydawnictwo_nadrzedne.id%3D+{{ original.pk }}">Powiązane</a></li>
    {% endif %}
    {% if original.pk %}
        <li><a href="/admin/bpp/wydawnictwo_zwarte_autor/?rekord__id__exact={{ original.pk }}">Autorzy</a></li>
    {% endif %}
    {{ block.super }}
{% endblock %}

{% block submit_buttons_bottom %}
    {{ block.super }}

    {% include "admin/pubmed_id_button_handler.html" %}
    {% include "admin/get_pbn_by_isbn_button_handler.html" %}
    {% include "admin/get_pbn_by_doi_button_handler.html" %}
    {% include "admin/liczba_cytowan_button_handler.html" %}
    {% include "admin/strona_tom_nr_zeszytu_button_handler.html" %}
    {% include "admin/liczba_arkuszy_wydawniczych.html" %}
    {% include "admin/uzupelnij_rok_wydawnictwo_zwarte_button_handler.html" %}

    <script type="text/javascript">
        (function ($) {
            // Gramatyka
            $('a').each(function () {
                var html = $(this).html();
                if (html.includes("Dodaj kolejne nagroda")) {
                }
                $(this).html(html.replace('Dodaj kolejne nagroda', 'Dodaj kolejną nagrodę'));
            });

            pub_id = $("#id_autorzy_set-__prefix__-rekord").val()

            if (pub_id) {
                btn = $("input[name=_continue]");
                tamze = $("<input/>")
                    .attr("id", "tamze")
                    .attr("class", "grp-button")
                    .attr("type", "button")
                    .attr("value", "Tamże");

                toz = tamze.clone()
                    .attr("id", "toz")
                    .attr("value", "Toż");

                btn.parent().parent().append($("<li/>").append(tamze));
                btn.parent().parent().append($("<li/>").append(toz));

                $("#tamze").click(function () {
                    data = {
                        "informacje": $("textarea[name=informacje]").val(),
                        "uwagi": $("textarea[name=uwagi]").val(),
                        "miejsce_i_rok": $("input[name=miejsce_i_rok]").val(),
                        "wydawca": $("select[name=wydawca]").val(),
                        "wydawca_opis": $("input[name=wydawca_opis]").val(),
                        // "www": $("input[name=www]").val(),
                        "isbn": $("input[name=isbn]").val(),
                        "e_isbn": $("input[name=e_isbn]").val(),
                        "rok": $("input[name=rok]").val(),

                        "charakter_formalny": $("select[name=charakter_formalny]").val(),
                        "jezyk": $("select[name=jezyk]").val(),
                        "typ_kbn": $("select[name=typ_kbn]").val(),

                        "punkty_kbn": $("input[name=punkty_kbn]").val(),
                        "impact_factor": $("input[name=impact_factor]").val(),
                        "index_copernicus": $("input[name=index_copernicus]").val(),
                        "punktacja_wewnetrzna": $("input[name=punktacja_wewnetrzna]").val(),
                        "punktacja_snip": $("input[name=punktacja_snip]").val(),

                        "kc_punkty_kbn": $("input[name=kc_punkty_kbn]").val(),
                        "kc_impact_factor": $("input[name=kc_impact_factor]").val(),
                        "kc_index_copernicus": $("input[name=kc_index_copernicus]").val()
                    }
                    window.onbeforeunload = function (e) {
                    };
                    location.href = "../../add/?" + $.param(data);
                });

                $("#toz").click(function () {
                    if (confirm('Utworzysz kopię tego rekordu. Czy kontynuować?')) {
                        window.onbeforeunload = function (e) {
                        };
                        location.href = "../../toz/" + pub_id;
                    }
                });
            }
        }(django.jQuery));
    </script>
{% endblock %}
