# Generated by Django 3.0.11 on 2020-12-25 18:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0227_auto_20201011_0010'),
        ('bpp', '0225_charakter_sloty_referat'),
    ]

    operations = [
    ]
