# Generated by Django 2.1.10 on 2019-10-27 16:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0187_auto_20191027_1141'),
    ]

    operations = [
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='numer_w_serii',
            field=models.CharField(blank=True, max_length=512, null=True),
        ),
    ]
