# Generated by Django 3.0.13 on 2021-03-16 22:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0250_auto_20210315_2104"),
    ]

    operations = [
        migrations.AddField(
            model_name="patent",
            name="slug",
            field=models.SlugField(blank=True, max_length=400, null=True, unique=True),
        ),
        migrations.AddField(
            model_name="praca_doktorska",
            name="slug",
            field=models.SlugField(blank=True, max_length=400, null=True, unique=True),
        ),
        migrations.AddField(
            model_name="praca_habilitacyjna",
            name="slug",
            field=models.SlugField(blank=True, max_length=400, null=True, unique=True),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="slug",
            field=models.SlugField(blank=True, max_length=400, null=True, unique=True),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte",
            name="slug",
            field=models.SlugField(blank=True, max_length=400, null=True, unique=True),
        ),
    ]
