# Generated by Django 3.0.14 on 2022-07-04 06:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0321_aktualna_jednostka_moze_byc_zadna"),
    ]

    operations = [
        migrations.AddField(
            model_name="praca_doktorska",
            name="opl_pub_amount",
            field=models.DecimalField(
                decimal_places=2, max_digits=20, null=True, verbose_name="Kwota"
            ),
        ),
        migrations.AddField(
            model_name="praca_doktorska",
            name="opl_pub_cost_free",
            field=models.BooleanField(null=True, verbose_name="Praca bez kosztów"),
        ),
        migrations.AddField(
            model_name="praca_doktorska",
            name="opl_pub_other",
            field=models.BooleanField(null=True, verbose_name="Inne"),
        ),
        migrations.AddField(
            model_name="praca_doktorska",
            name="opl_pub_research_or_development_projects",
            field=models.BooleanField(
                null=True,
                verbose_name="Zasoby finansowe badawcze lub rozwojowe projektów",
            ),
        ),
        migrations.AddField(
            model_name="praca_doktorska",
            name="opl_pub_research_potential",
            field=models.BooleanField(
                null=True, verbose_name="Zasoby finansowe potencjału naukowego"
            ),
        ),
        migrations.AddField(
            model_name="praca_habilitacyjna",
            name="opl_pub_amount",
            field=models.DecimalField(
                decimal_places=2, max_digits=20, null=True, verbose_name="Kwota"
            ),
        ),
        migrations.AddField(
            model_name="praca_habilitacyjna",
            name="opl_pub_cost_free",
            field=models.BooleanField(null=True, verbose_name="Praca bez kosztów"),
        ),
        migrations.AddField(
            model_name="praca_habilitacyjna",
            name="opl_pub_other",
            field=models.BooleanField(null=True, verbose_name="Inne"),
        ),
        migrations.AddField(
            model_name="praca_habilitacyjna",
            name="opl_pub_research_or_development_projects",
            field=models.BooleanField(
                null=True,
                verbose_name="Zasoby finansowe badawcze lub rozwojowe projektów",
            ),
        ),
        migrations.AddField(
            model_name="praca_habilitacyjna",
            name="opl_pub_research_potential",
            field=models.BooleanField(
                null=True, verbose_name="Zasoby finansowe potencjału naukowego"
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_amount",
            field=models.DecimalField(
                decimal_places=2, max_digits=20, null=True, verbose_name="Kwota"
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_cost_free",
            field=models.BooleanField(null=True, verbose_name="Praca bez kosztów"),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_other",
            field=models.BooleanField(null=True, verbose_name="Inne"),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_research_or_development_projects",
            field=models.BooleanField(
                null=True,
                verbose_name="Zasoby finansowe badawcze lub rozwojowe projektów",
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_research_potential",
            field=models.BooleanField(
                null=True, verbose_name="Zasoby finansowe potencjału naukowego"
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_amount",
            field=models.DecimalField(
                decimal_places=2, max_digits=20, null=True, verbose_name="Kwota"
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_cost_free",
            field=models.BooleanField(null=True, verbose_name="Praca bez kosztów"),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_other",
            field=models.BooleanField(null=True, verbose_name="Inne"),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_research_or_development_projects",
            field=models.BooleanField(
                null=True,
                verbose_name="Zasoby finansowe badawcze lub rozwojowe projektów",
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_research_potential",
            field=models.BooleanField(
                null=True, verbose_name="Zasoby finansowe potencjału naukowego"
            ),
        ),
    ]
