# Generated by Django 3.2.15 on 2022-09-21 19:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0328_alter_uczelnia_wymagaj_informacji_o_oplatach"),
        ("bpp", "0329_auto_20220921_2030"),
    ]

    operations = []
