# Generated by Django 3.0.9 on 2020-10-10 22:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0226_rekord_mat_status"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="ukryj_status_korekty",
            options={
                "verbose_name": "ustawienie ukrywania statusu korekty",
                "verbose_name_plural": "ustawienia ukrywania statusów korekt",
            },
        ),
        migrations.AddField(
            model_name="ukryj_status_korekty",
            name="api",
            field=models.BooleanField(default=True),
        ),
        migrations.AlterField(
            model_name="ukryj_status_korekty",
            name="multiwyszukiwarka",
            field=models.BooleanField(
                default=True,
                help_text="Nie dotyczy użytkownika zalogowanego. Użytkownik zalogowany widzi wszystkie prace w wyszukiwaniu. ",
            ),
        ),
    ]
