.session_security_overlay{position:fixed;top:0;left:0;width:100%;height:100%;background:#000;z-index:1001;opacity:.75;-moz-opacity:0.75;filter:alpha(opacity=75)}.session_security_modal{position:fixed;top:25%;left:25%;width:50%;padding:16px;background:#fff;color:#333;z-index:1002;overflow:auto;text-align:center}