# Generated by Django 3.0.14 on 2021-08-17 19:01
from django.db import migrations

from django.contrib.postgres.operations import CreateExtension


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0286_auto_20210814_0104"),
    ]

    operations = [CreateExtension("pg_trgm")]
