# Generated by Django 2.1.7 on 2019-07-07 18:29

import bpp.models.cache
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0166_auto_20190702_1200'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cache_punktacja_autora',
            name='rekord_id',
            field=bpp.models.cache.TupleField(base_field=models.IntegerField(), db_index=True, size=2),
        ),
        migrations.AlterField(
            model_name='cache_punktacja_dyscypliny',
            name='rekord_id',
            field=bpp.models.cache.TupleField(base_field=models.IntegerField(), db_index=True, size=2),
        ),
        migrations.AddField(
            model_name='cache_punktacja_autora',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='cache_punktacja_dyscypliny',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
            preserve_default=False,
        ),
    ]
