# Generated by Django 3.0.14 on 2021-09-05 20:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("pbn_api", "0032_sent_data_pbn_uid"),
    ]

    operations = [
        migrations.AddField(
            model_name="sentdata",
            name="typ_rekordu",
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
    ]
