# Generated by Django 3.0.14 on 2022-01-09 01:39

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0309_auto_20211110_0000"),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0310_fix_refresh_cache_deadlocks")
        ),
    ]
