# Generated by Django 3.0.14 on 2022-06-15 19:40

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0320_autor_aktualny_pole_znika"),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql(
                "0321_aktualna_jednostka_moze_byc_zadna"
            )
        )
    ]
