# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-19 09:40
from __future__ import unicode_literals

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0106_pokazuj_uczelnia'),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("107_bpp_rekord")
        ),

        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("107_bpp_autorzy")
        ),

        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("107_cache_functions")
        ),
    ]
