# Generated by Django 3.0.11 on 2021-03-12 11:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0246_auto_20210312_1228"),
    ]

    operations = [
        migrations.AddField(
            model_name="funkcja_autora",
            name="pokazuj_za_nazwiskiem",
            field=models.BooleanField(
                default=False,
                help_text="Zaznaczenie tego pola sprawi, że ta funkcja\n        "
                "będzie wyświetlana na stronie autora, za nazwiskiem.",
            ),
        ),
    ]
