# Generated by Django 3.0.14 on 2022-05-03 21:51

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0318_jedno_podstawowe_miejsce_pracy"),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql(
                "0319_aktualna_jednostka_to_podstawowe_miejsce"
            )
        )
    ]
