/**
 * @fileOverview CSS for jquery-autocomplete, the jQuery Autocompleter
 * @author <a href="mailto:dylan@dyve.net">Dylan Verheul</a>
 * @license MIT | GPL | Apache 2.0, see LICENSE.txt
 * @see https://github.com/dyve/jquery-autocomplete
 */
.acResults {
	padding: 0px;
	border: 1px solid WindowFrame;
	background-color: Window;
	overflow: hidden;
}

.acResults ul {
	margin: 0px;
	padding: 0px;
	list-style-position: outside;
	list-style: none;
}

.acResults ul li {
	margin: 0px;
	padding: 2px 5px;
	cursor: pointer;
	display: block;
	font: menu;
	font-size: 12px;
	overflow: hidden;
}

.acLoading {
	background : url('../img/indicator.gif') right center no-repeat;
}

.acSelect {
	background-color: Highlight;
	color: HighlightText;
}
