# Generated by Django 3.0.14 on 2021-11-22 00:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("ewaluacja2021", "0008_auto_20211122_0103"),
    ]

    operations = [
        migrations.AddField(
            model_name="zamowienienaraport",
            name="status",
            field=models.CharField(blank=True, default="", max_length=255, null=True),
        ),
    ]
