# Generated by Django 3.2.15 on 2022-09-21 18:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0327_uczelnia_pokazuj_formularz_zglaszania_publikacji"),
    ]

    operations = [
        migrations.AddField(
            model_name="charakter_formalny",
            name="charakter_crossref",
            field=models.PositiveSmallIntegerField(
                blank=True,
                choices=[("1", "journal-article"), ("2", "proceedings-article")],
                default=None,
                null=True,
                unique=True,
                verbose_name="Charakter w CrossRef",
            ),
        ),
    ]
