# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-04-30 16:54
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0131_liczba_cytowan'),
    ]

    operations = [
        migrations.RunSQL(
            "ALTER TABLE bpp_wydawnictwo_ciagle_autor ADD CONSTRAINT bpp_wydawnictwo_ciagle_autor_unique_rekord_id_kolejnosc "
            "UNIQUE (rekord_id, kolejnosc) DEFERRABLE INITIALLY DEFERRED ;",

            "ALTER TABLE bpp_wydawnictwo_ciagle_autor DROP CONSTRAINT bpp_wydawnictwo_ciagle_autor_unique_rekord_id_kolejnosc "
        ),

        migrations.RunSQL(
            "ALTER TABLE bpp_wydawnictwo_zwarte_autor ADD CONSTRAINT bpp_wydawnictwo_zwarte_autor_unique_rekord_id_kolejnosc "
            "UNIQUE (rekord_id, kolejnosc) DEFERRABLE INITIALLY DEFERRED ;",

            "ALTER TABLE bpp_wydawnictwo_zwarte_autor DROP CONSTRAINT bpp_wydawnictwo_zwarte_autor_unique_rekord_id_kolejnosc "
        ),

        migrations.RunSQL(
            "ALTER TABLE bpp_patent_autor ADD CONSTRAINT bpp_patent_autor_unique_rekord_id_kolejnosc "
            "UNIQUE (rekord_id, kolejnosc) DEFERRABLE INITIALLY DEFERRED ;",

            "ALTER TABLE bpp_patent_autor DROP CONSTRAINT bpp_patent_autor_unique_rekord_id_kolejnosc "
        ),

    ]
