# Generated by Django 2.1.7 on 2019-09-05 18:20

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0177_cache_punktacja_autora_query'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='cache_punktacja_autora_query',
            table='bpp_cache_punktacja_autora',
        ),
    ]
