# Generated by Django 3.0.11 on 2021-03-15 19:30

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0248_autorzy_mat_idx"),
    ]

    operations = [
        migrations.CreateModel(
            name="Dyscyplina_Zrodla",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "dyscyplina",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="bpp.Dyscyplina_Naukowa",
                    ),
                ),
                (
                    "zrodlo",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="bpp.Zrodlo"
                    ),
                ),
            ],
            options={
                "verbose_name": "przypisanie dyscypliny do źródła",
                "verbose_name_plural": "przypisania dyscyplin do źródeł",
                "ordering": ["zrodlo__nazwa", "dyscyplina__nazwa"],
                "unique_together": {("zrodlo", "dyscyplina")},
            },
        ),
    ]
