# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-11-10 23:36
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0113_auto_20171111_0035'),
    ]

    operations = [
        migrations.RenameField(
            model_name='autor',
            old_name='pokazuj_na_stronach_jednostek',
            new_name='pokazuj',
        ),
    ]
