# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-06-12 21:04
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0134_liczba_cytowan_wyszukaj'),
        ('bpp', '0134_uczelnia_domyslnie_afiliuje'),
    ]

    operations = [
    ]
