# Generated by Django 3.0.14 on 2021-07-13 20:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("pbn_api", "0013_oswiadczenieinstytucji_publikacjainstytucji"),
    ]

    operations = [
        migrations.AlterField(
            model_name="publikacjainstytucji",
            name="publicationVersion",
            field=models.UUIDField(blank=True, null=True),
        ),
    ]
