# Generated by Django 3.0.14 on 2021-07-13 20:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("pbn_api", "0014_auto_20210713_2229"),
    ]

    operations = [
        migrations.AlterField(
            model_name="publikacjainstytucji",
            name="publicationType",
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name="publikacjainstytucji",
            name="publicationYear",
            field=models.PositiveSmallIntegerField(blank=True, null=True),
        ),
    ]
