# Generated by Django 3.0.11 on 2021-03-15 20:04

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0249_dyscyplina_zrodla"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="dyscyplina_zrodla",
            options={
                "ordering": ["zrodlo__nazwa", "dyscyplina__nazwa"],
                "verbose_name": "przypisanie dyscypliny do źródła",
                "verbose_name_plural": "przypisanie dyscyplin do źródła",
            },
        ),
    ]
