# Generated by Django 3.0.14 on 2021-08-18 21:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("pbn_api", "0029_indeksy_gist_inne_tabele"),
    ]

    operations = [
        migrations.AlterField(
            model_name="conference",
            name="verificationLevel",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="conference",
            name="verified",
            field=models.BooleanField(db_index=True, default=False),
        ),
        migrations.AlterField(
            model_name="institution",
            name="verificationLevel",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="institution",
            name="verified",
            field=models.BooleanField(db_index=True, default=False),
        ),
        migrations.AlterField(
            model_name="journal",
            name="verificationLevel",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="journal",
            name="verified",
            field=models.BooleanField(db_index=True, default=False),
        ),
        migrations.AlterField(
            model_name="publication",
            name="verificationLevel",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="publication",
            name="verified",
            field=models.BooleanField(db_index=True, default=False),
        ),
        migrations.AlterField(
            model_name="publisher",
            name="verificationLevel",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="publisher",
            name="verified",
            field=models.BooleanField(db_index=True, default=False),
        ),
        migrations.AlterField(
            model_name="scientist",
            name="verificationLevel",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="scientist",
            name="verified",
            field=models.BooleanField(db_index=True, default=False),
        ),
    ]
