{% extends "base.html" %}
{% load humanize %}

{% block extratitle %}
    Import dyscyplin naukowych
{% endblock %}

{% block breadcrumbs %}
    {{ block.super }}
    <li><a href="..">import dyscyplin</a></li>
    <li class="current">utwórz nowy import</li>
{% endblock %}


{% block content %}
    {% load crispy_forms_tags %}
    {% crispy form %}
{% endblock %}
