{% extends "base.html" %}
{% load columns %}

{% block extratitle %}
    {{ wydzial }}
{% endblock %}

{% block breadcrumbs %}
    {{ block.super }}
    <li class="current">{{ wydzial }}</li>
{% endblock %}

{% block content %}
    <h1>{{ wydzial }}</h1>
    {% include "browse/go_to_admin_change.html" with url="admin:bpp_wydzial_change" pk=wydzial.pk group="struktura" %}
    {#    <h2><a href="{% url "bpp:browse_uczelnia" wydzial.uczelnia.slug %}">#}
    {#    {{ wydzial.uczelnia }}#}
    {#    </a></h2>#}

    <div class="row" style="line-height: 180%;">
        {% for jednostka in wydzial.jednostki %}
            <div class="large-6 medium-12 small-12 columns">
                <a href="{% url "bpp:browse_jednostka" jednostka.slug %}">
                    {{ jednostka.nazwa }}
                </a>
            </div>

        {% endfor %}
    </div>


{% endblock %}