# Generated by Django 3.2.15 on 2022-10-02 20:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("dynamic_columns", "0001_initial"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="modeladmincolumn",
            options={"ordering": ("parent", "ordering")},
        ),
        migrations.AddField(
            model_name="modeladmincolumn",
            name="enabled",
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name="modeladmincolumn",
            name="ordering",
            field=models.PositiveSmallIntegerField(default=1),
            preserve_default=False,
        ),
        migrations.DeleteModel(
            name="ModelAdminSetting",
        ),
    ]
