# Generated by Django 3.0.11 on 2021-02-28 12:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("taggit", "0003_taggeditem_add_unique_index"),
        ("bpp", "0238_drop_pesel_md5"),
    ]

    operations = [
        migrations.AddField(
            model_name="autor",
            name="pbn_uuid",
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="autor",
            name="system_kadrowy_id",
            field=models.PositiveSmallIntegerField(
                blank=True,
                help_text="Identyfikator cyfrowy, używany do matchowania autora z danymi z systemu kadrowego Uczelni",
                null=True,
                verbose_name="Identyfikator w systemie kadrowym",
            ),
        ),
        migrations.AddField(
            model_name="autor_jednostka",
            name="podstawowe_miejsce_pracy",
            field=models.NullBooleanField(),
        ),
    ]
