# Generated by Django 3.0.14 on 2021-11-09 23:00

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0308_ewaluacja_upowaznienia_view"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="wydawnictwo_ciagle_streszczenie",
            options={
                "verbose_name": "streszczenie wydawnictwa ciągłego",
                "verbose_name_plural": "streszczenia wydawnictw ciągłych",
            },
        ),
        migrations.AlterModelOptions(
            name="wydawnictwo_zwarte_streszczenie",
            options={
                "verbose_name": "streszczenie wydawnictwa zwartego",
                "verbose_name_plural": "streszczenia wydawnictw zwatrtych",
            },
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle_streszczenie",
            name="rekord",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="streszczenia",
                to="bpp.Wydawnictwo_Ciagle",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte_streszczenie",
            name="rekord",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="streszczenia",
                to="bpp.Wydawnictwo_Zwarte",
            ),
        ),
    ]
