<div class="ui-widget">
    <div class="ui-state-highlight ui-corner-all"
         style="margin-top: 5px; padding: 0 .8em;">
        <p><span class="ui-icon ui-icon-info"
                 style="float: left; margin-right: .7em;"></span>
            <strong>Informacja: </strong>{{ message }}</p>
    </div>

</div>