# Generated by Django 3.0.14 on 2021-10-10 21:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0297_liczba_n_uczelni"),
        ("bpp", "0304_auto_20211010_2247"),
    ]

    operations = []
