# Generated by Django 3.0.9 on 2020-10-07 08:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0224_auto_20201007_0956"),
    ]

    operations = [
        migrations.AddField(
            model_name="ukryj_status_korekty",
            name="multiwyszukiwarka",
            field=models.BooleanField(
                default=True,
                help_text="Nie dotyczy użytkownika zalogowanego. Użytkownik zalogowany widzi wszystkie prace. ",
            ),
        ),
        migrations.AddField(
            model_name="ukryj_status_korekty",
            name="rankingi",
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name="ukryj_status_korekty",
            name="raporty",
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name="ukryj_status_korekty",
            name="sloty",
            field=models.BooleanField(default=True),
        ),
    ]
