{% extends "base.html" %}
{% load prace %}

{% block extratitle %}
    {{ rekord.tytul_oryginalny|striptags }}
{% endblock %}


{% block breadcrumbs %}
    {{ block.super }}
    <li><a href="{% url "multiseek:index" %}">Wyszukiwanie</a></li>
    <li class="current">{{ rekord.tytul_oryginalny|truncatewords:12|close_tags|safe}}</li>
{% endblock %}


{% block content %}
    {% include "browse/praca_tabela.html" with praca=rekord.original autorzy=rekord.original.autorzy_dla_opisu rekord=rekord links="normal"%}
    {% include "browse/google_scholar.html" with praca=rekord.original autorzy=rekord.original.autorzy_dla_opisu rekord=rekord %}

    {% with rekord as r %}
        {% include "browse/go_to_admin_change.html" with url="admin:"|add:r.content_type.app_label|add:"_"|add:r.content_type.model|add:"_change" pk=r.object_id  group="wprowadzanie danych" %}
        {% include "browse/go_to_admin_list.html" with url="admin:"|add:r.content_type.app_label|add:"_"|add:r.content_type.model|add:"_add" pk=r.object_id  group="wprowadzanie danych" text="dodaj nowy rekord" %}
    {% endwith %}

{% endblock %}
