# Generated by Django 3.0.14 on 2022-06-15 19:40

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0319_aktualna_jednostka_to_podstawowe_miejsce'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='autor',
            name='aktualny',
        ),
    ]
