# Generated by Django 3.0.14 on 2021-11-02 19:14

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("rozbieznosci_dyscyplin", "0011_null_is_wrong"),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql(
                "0012_rozbieznosci_dyscyplin_zrodel", app_name="rozbieznosci_dyscyplin"
            )
        )
    ]
