{% load pagination_tags %}
<ul class="menu hide-for-print">
    <li><a href="#"><i class="fi-database"></i> rekordów: {{ paginator_count }}</a></li>
    {% if live == "0" %}
        <li><a href=".."><i class="fi-arrow-left"></i> powrót do formularza</a>
        </li>
    {% endif %}

    {% if paginator_count > 0 and paginator_count < max_rows %}
        {% if live == "1" %}
            <li>
                <a target="_blank"
                   href="/multiseek/results/?all=1&print=1{% if print_removed %}&print-removed=1{% endif %}"><i
                        class="fi-print"></i> drukuj</a>
            </li>
            {% if request.GET.all != "1" %}
                <li>
                    <a target="_blank" href="/multiseek/results/?all=1"><i class="fi-page-multiple"></i>
                        wyświetl&nbsp;wszystkie</a>
                </li>
            {% endif %}
        {% else %}
            <li>
                <a href="?all=1&print=1{% if print_removed %}&print-removed=1{% endif %}"><i
                        class="fi-print"></i> drukuj</a>
            </li>
            {% if request.GET.all != "1" and paginator.num_pages > 1 %}
                <li><a href="?all=1"><i class="fi-page-multiple"></i> wyświetl wszystkie</a></li>
            {% endif %}
        {% endif %}
    {% endif %}
</ul>
{% if paginator.num_pages > 1 %}
{% paginate %}
{% endif %}