# Generated by Django 3.0.11 on 2021-03-07 11:04

import django.contrib.postgres.fields.jsonb
import django.core.serializers.json
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("import_pracownikow", "0004_auto_20210307_1110"),
    ]

    operations = [
        migrations.AddField(
            model_name="importpracownikowrow",
            name="log_zmian",
            field=django.contrib.postgres.fields.jsonb.JSONField(
                blank=True,
                encoder=django.core.serializers.json.DjangoJSONEncoder,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="importpracownikowrow",
            name="dane_z_xls",
            field=django.contrib.postgres.fields.jsonb.JSONField(
                blank=True,
                encoder=django.core.serializers.json.DjangoJSONEncoder,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="importpracownikowrow",
            name="dane_znormalizowane",
            field=django.contrib.postgres.fields.jsonb.JSONField(
                blank=True,
                encoder=django.core.serializers.json.DjangoJSONEncoder,
                null=True,
            ),
        ),
    ]
