# Generated by Django 3.0.7 on 2020-07-27 21:07

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0217_grant"),
    ]

    operations = [
        migrations.AddField(
            model_name="praca_doktorska",
            name="grant",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="bpp.Grant",
            ),
        ),
        migrations.AddField(
            model_name="praca_habilitacyjna",
            name="grant",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="bpp.Grant",
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="grant",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="bpp.Grant",
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte",
            name="grant",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="bpp.Grant",
            ),
        ),
    ]
