# Generated by Django 3.0.7 on 2020-06-07 18:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0212_upowaznienie_pbn"),
        ("bpp", "0212_charakter_formalny_charakter_ogolny"),
    ]

    operations = []
