API_BRAK_PARAMETRU = "Brak parametru do przeprowadzenia zapytania. "

PUBMED_PO_TYTULE_BRAK = "Szukając po tytule, nie znaleziono żadnych rekordów. "
PUBMED_PO_TYTULE_WIELE = "Znaleziono więcej, niz 1 rekord. "
PUBMED_BRAK_PARAMETRU = API_BRAK_PARAMETRU


# Używane przez testy:
PUBMED_TITLE_NONEXISTENT = "__nonexistent__"
PUBMED_TITLE_MULTIPLE = "__multiple__"
