# Generated by Django 2.1.7 on 2019-09-02 23:03

import bpp.models.cache
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('rozbieznosci_dyscyplin', '0002_rok_2017_i_wyzej'),
    ]

    operations = [
        migrations.CreateModel(
            name='BrakPrzypisaniaView',
            fields=[
                ('id', bpp.models.cache.TupleField(base_field=models.IntegerField(), primary_key=True, serialize=False, size=3)),
                ('rok', models.IntegerField()),
            ],
            options={
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='RozbieznePrzypisaniaView',
            fields=[
                ('id', bpp.models.cache.TupleField(base_field=models.IntegerField(), primary_key=True, serialize=False, size=3)),
                ('rok', models.IntegerField()),
            ],
            options={
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='RozbieznosciView',
            fields=[
                ('id', bpp.models.cache.TupleField(base_field=models.IntegerField(), primary_key=True, serialize=False, size=3)),
                ('rok', models.IntegerField()),
            ],
            options={
                'managed': False,
            },
        ),
    ]
