# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-12-18 23:37
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0150_auto_20181125_1202'),
        ('bpp', '0151_snip'),
    ]

    operations = [
    ]
