# Generated by Django 3.0.14 on 2021-08-08 10:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("pbn_api", "0020_przemapuj"),
    ]

    operations = [
        migrations.AlterField(
            model_name="scientist",
            name="lastName",
            field=models.TextField(blank=True, db_index=True, null=True),
        ),
        migrations.AlterField(
            model_name="scientist",
            name="name",
            field=models.TextField(blank=True, db_index=True, null=True),
        ),
        migrations.AlterField(
            model_name="scientist",
            name="orcid",
            field=models.TextField(blank=True, db_index=True, null=True),
        ),
        migrations.AlterField(
            model_name="scientist",
            name="pbnId",
            field=models.TextField(blank=True, db_index=True, null=True),
        ),
        migrations.AlterField(
            model_name="scientist",
            name="polonUid",
            field=models.TextField(blank=True, db_index=True, null=True),
        ),
        migrations.AlterField(
            model_name="scientist",
            name="qualifications",
            field=models.TextField(
                blank=True, db_index=True, null=True, verbose_name="Tytuł"
            ),
        ),
    ]
