{% load user_in_group %}{% if request.user.is_superuser or request.user|has_group:group %}
    <div class="callout warning hide-for-print">
        <a target="_blank" href="{% url url pk %}"><i class="fi-page-edit"></i> {{ text|default:"otwórz do edycji" }}</a>
    </div>
{% endif %}