from django_bpp import urls

urls


from bpp.tests.util import *  # noqa
from bpp.tests.util import setup_model_bakery

setup_model_bakery()
#
# from test_abstract import *
# from test_admin import *
# from test_autocomplete import *
# from test_cache import *
# from test_commands import *
# from test_imports import *
# from test_jezyk_polski import *
# from test_management import *
# from test_models import *
# from test_multiseek import *
# from test_tasks import *
# from test_templatetags import *
# from test_util import *
#
# from test_views import *
# from test_reports import *
#
# import os
# if os.getenv("NO_SELENIUM", "0") != "1":
#    from test_selenium import *
# from test_selenium.test_admin import *
