<script type="text/javascript">

    $('document').ready(function () {
        $("input[type=button]").button();
        $("input[type=submit]").button();
        $("input[type=radio]").buttonset();
    });

</script>