# Generated by Django 3.0.14 on 2021-11-02 16:55

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0307_streszczenia"),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0308_ewaluacja_upowaznienia_view")
        )
    ]
