# Generated by Django 3.2.15 on 2022-10-09 15:31

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0332_pbn_zawsze_uid_uczelni"),
        ("zglos_publikacje", "0013_auto_20220910_2114"),
    ]

    operations = [
        migrations.AddField(
            model_name="zgloszenie_publikacji_autor",
            name="kierunek_studiow",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="bpp.kierunek_studiow",
            ),
        ),
    ]
