# Generated by Django 3.0.11 on 2021-03-08 11:46

from decimal import Decimal

import django.contrib.postgres.fields.jsonb
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0245_auto_20210308_1246"),
        ("import_list_if", "0001_initial"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="importlistif",
            options={},
        ),
        migrations.CreateModel(
            name="ImportListIfRow",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("dane_z_xls", django.contrib.postgres.fields.jsonb.JSONField()),
                (
                    "impact_factor",
                    models.DecimalField(
                        blank=True,
                        decimal_places=3,
                        default=Decimal("0.000"),
                        max_digits=6,
                        null=True,
                    ),
                ),
                ("zintegrowano", models.BooleanField(default=False)),
                (
                    "parent",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="import_list_if.ImportListIf",
                    ),
                ),
                (
                    "zrodlo",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="bpp.Zrodlo",
                    ),
                ),
            ],
        ),
    ]
