{% extends "base.html" %}

{% block extratitle %}
    Zaloguj się
{% endblock %}

{% block breadcrumbs %}
    {{ block.super }}
    <li class="current">Logowanie</a>
{% endblock %}

{% block content %}
    <div class="grid-x align-center">
        <div class="large-6 medium-8 small-12 cell">
            {% if request.user.is_anonymous %}
                {% load crispy_forms_tags %}
                {% crispy form %}
                <a href="{% url "password_reset" %}">Zapomniałem/am hasła.</a>
            {% else %}
                <h1>Konto zalogowane do systemu</h1>
                <p>
                Jesteś już zalogowany/a.</p><p>
                Jeżeli trafiasz na tą stronę po kliknięciu linku do jakiejś funkcji, może to oznaczać
                że Twoje konto nie posiada odpowiednich uprawnień do skorzystania z niej.
            </p>
            {% endif %}
        </div>
    </div>

    <script>
        $(document).ready(function () {
            $("#id_username").focus();
        });
    </script>

{% endblock %}
