# Generated by Django 2.1.7 on 2019-07-01 11:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0163_cachequeue'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='cachequeue',
            options={'ordering': ('-created_on',)},
        ),
        migrations.RemoveField(
            model_name='cachequeue',
            name='task_id',
        ),
        migrations.AlterField(
            model_name='cachequeue',
            name='created_on',
            field=models.DateTimeField(blank=True),
        ),
    ]
