# Generated by Django 3.0.11 on 2021-03-12 11:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0245_auto_20210308_1246"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="autor_jednostka",
            options={
                "ordering": ["autor__nazwisko", "rozpoczal_prace", "jednostka__nazwa"],
                "verbose_name": "powiązanie autor-jednostka",
                "verbose_name_plural": "powiązania autor-jednostka",
            },
        ),
    ]
