# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-04-17 10:59
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0129_zewnetrznebazydanychview'),
    ]

    operations = [
        migrations.AddField(
            model_name='uczelnia',
            name='clarivate_password',
            field=models.CharField(blank=True, max_length=50, null=True, verbose_name='Hasło'),
        ),
        migrations.AddField(
            model_name='uczelnia',
            name='clarivate_username',
            field=models.CharField(blank=True, max_length=50, null=True, verbose_name='Nazwa użytkownika'),
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='liczba_cytowan',
            field=models.PositiveIntegerField(blank=True, null=True, verbose_name='Liczba cytowań'),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='liczba_cytowan',
            field=models.PositiveIntegerField(blank=True, null=True, verbose_name='Liczba cytowań'),
        ),
    ]
