# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-23 22:26
from __future__ import unicode_literals

from decimal import Decimal
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0103_widoki_nowe_sumy'),
    ]

    operations = [
        migrations.CreateModel(
            name='Nowe_Sumy_View',
            fields=[
                ('impact_factor', models.DecimalField(db_index=True, decimal_places=3, default=Decimal('0.000'), max_digits=6)),
                ('punkty_kbn', models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Punkty KBN')),
                ('index_copernicus', models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Index Copernicus')),
                ('punktacja_wewnetrzna', models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Punktacja wewnętrzna')),
                ('kc_impact_factor', models.DecimalField(blank=True, db_index=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', max_digits=6, null=True, verbose_name='KC: Impact factor')),
                ('kc_punkty_kbn', models.DecimalField(blank=True, db_index=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', max_digits=6, null=True, verbose_name='KC: Punkty KBN')),
                ('kc_index_copernicus', models.DecimalField(blank=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', max_digits=6, null=True, verbose_name='KC: Index Copernicus')),
                ('weryfikacja_punktacji', models.BooleanField(default=False)),
                ('autor', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, primary_key=True, serialize=False, to='bpp.Autor')),
                ('jednostka', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, primary_key=True, to='bpp.Jednostka')),
                ('rok', models.IntegerField()),
            ],
            options={
                'managed': False,
            },
        ),
    ]
