# Generated by Django 3.0.14 on 2021-06-21 07:47

from django.db import migrations, models

import django.contrib.postgres.fields.jsonb


class Migration(migrations.Migration):

    dependencies = [
        ("pbn_api", "0011_auto_20210509_2339"),
    ]

    operations = [
        migrations.AddField(
            model_name="scientist",
            name="from_institution_api",
            field=models.NullBooleanField(db_index=True),
        ),
        migrations.AlterField(
            model_name="sentdata",
            name="data_sent",
            field=django.contrib.postgres.fields.jsonb.JSONField(
                verbose_name="Wysłane dane"
            ),
        ),
        migrations.AlterField(
            model_name="sentdata",
            name="exception",
            field=models.TextField(
                blank=True, max_length=65535, null=True, verbose_name="Kod błędu"
            ),
        ),
        migrations.AlterField(
            model_name="sentdata",
            name="last_updated_on",
            field=models.DateTimeField(auto_now=True, verbose_name="Data operacji"),
        ),
        migrations.AlterField(
            model_name="sentdata",
            name="uploaded_okay",
            field=models.BooleanField(
                db_index=True, default=True, verbose_name="Wysłano poprawnie"
            ),
        ),
    ]
