# Generated by Django 2.1.7 on 2019-03-24 17:26

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('import_dyscyplin', '0012_import_dyscyplin_row_dyscyplina_ostateczna'),
    ]

    operations = [
        migrations.CreateModel(
            name='Kolumna',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('nazwa_w_pliku', models.CharField(help_text='Nazwa kolumny po stronie pliku importu', max_length=250)),
                ('rodzaj_pola', models.CharField(choices=[('nazwisko', 'nazwisko'), ('imię', 'imię'), ('pesel', 'pesel'), ('orcid', 'orcid'), ('nazwa jednostki', 'nazwa jednostki'), ('wydział', 'wydział'), ('dyscyplina', 'dyscyplina'), ('kod dyscypliny', 'kod dyscypliny'), ('procent dyscypliny', 'procent dyscypliny'), ('subdyscyplina', 'subdyscyplina'), ('kod subdyscypliny', 'kod subdyscypliny'), ('procent subdyscypliny', 'procent subdyscypliny')], max_length=50)),
                ('parent', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='import_dyscyplin.Import_Dyscyplin')),
            ],
        ),
        migrations.RemoveField(
            model_name='import_dyscyplin_row',
            name='dyscyplina_ostateczna',
        ),
        migrations.AddField(
            model_name='import_dyscyplin_row',
            name='procent_dyscypliny',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True),
        ),
        migrations.AddField(
            model_name='import_dyscyplin_row',
            name='procent_subdyscypliny',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True),
        ),
        migrations.AddField(
            model_name='import_dyscyplin',
            name='kolumny',
            field=models.ManyToManyField(to='import_dyscyplin.Kolumna'),
        ),
    ]
