# Generated by Django 3.0.14 on 2021-05-29 21:51

from django.db import migrations


def wyzeruj_zrodla_pbn_uid_id(apps, schema_editor):
    Zrodlo = apps.get_model("bpp", "Zrodlo")
    Zrodlo.objects.exclude(pbn_uid_id=None).update(pbn_uid_id=None)


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0268_auto_20210519_0238"),
    ]

    operations = [
        migrations.RunPython(wyzeruj_zrodla_pbn_uid_id, migrations.RunPython.noop),
    ]
