# Generated by Django 3.0.11 on 2021-04-25 23:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0260_jednostka_pbn_uid"),
    ]

    operations = [
        migrations.AddField(
            model_name="uczelnia",
            name="pbn_api_root",
            field=models.URLField(
                default="https://pbn-micro-alpha.opi.org.pl",
                verbose_name="Adres API w PBN",
            ),
        ),
        migrations.AddField(
            model_name="uczelnia",
            name="pbn_app_name",
            field=models.CharField(
                blank=True,
                max_length=128,
                null=True,
                verbose_name="Nazwa aplikacji w PBN",
            ),
        ),
        migrations.AddField(
            model_name="uczelnia",
            name="pbn_app_token",
            field=models.CharField(
                blank=True,
                max_length=128,
                null=True,
                verbose_name="Token aplikacji w PBN",
            ),
        ),
    ]
