# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-20 00:01
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0097_nagrody'),
    ]

    operations = [
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='praca_wybitna',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='uzasadnienie_wybitnosci',
            field=models.TextField(blank=True, default='', verbose_name='Uzasadnienie wybitności'),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='praca_wybitna',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='uzasadnienie_wybitnosci',
            field=models.TextField(blank=True, default='', verbose_name='Uzasadnienie wybitności'),
        ),
    ]
