# Generated by Django 3.2.14 on 2022-07-10 21:31

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
        ("zglos_publikacje", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="zgloszenie_publikacji",
            name="content_type",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="contenttypes.contenttype",
            ),
        ),
        migrations.AddField(
            model_name="zgloszenie_publikacji",
            name="email",
            field=models.EmailField(
                default="test@test.pl",
                max_length=254,
                verbose_name="E-mail zgłaszającego",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="zgloszenie_publikacji",
            name="object_id",
            field=models.BigIntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="zgloszenie_publikacji",
            name="status",
            field=models.PositiveSmallIntegerField(
                choices=[
                    (0, "nowe zgłoszenie"),
                    (1, "dodane do bazy"),
                    (2, "wymaga uzupełnienia"),
                    (3, "odrzucono"),
                    (4, "spam"),
                ],
                default=0,
            ),
        ),
        migrations.AddField(
            model_name="zgloszenie_publikacji",
            name="utworzono",
            field=models.DateTimeField(
                auto_now_add=True, null=True, verbose_name="Utworzono"
            ),
        ),
    ]
