# Generated by Django 3.0.4 on 2020-05-14 11:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0210_uczelnia_sortuj_jednostki_alfabetycznie"),
    ]

    operations = [
        migrations.AddField(
            model_name="praca_doktorska",
            name="oznaczenie_wydania",
            field=models.CharField(blank=True, max_length=400, null=True),
        ),
        migrations.AddField(
            model_name="praca_habilitacyjna",
            name="oznaczenie_wydania",
            field=models.CharField(blank=True, max_length=400, null=True),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte",
            name="oznaczenie_wydania",
            field=models.CharField(blank=True, max_length=400, null=True),
        ),
    ]
