# Generated by Django 3.2.14 on 2022-07-07 22:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("integrator2", "0003_django110_py3k"),
    ]

    operations = [
        migrations.AlterField(
            model_name="listaministerialnaelement",
            name="moze_byc_zintegrowany_automatycznie",
            field=models.BooleanField(default=None, null=True),
        ),
    ]
