# Generated by Django 2.2.10 on 2020-03-16 18:14

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0206_auto_20200315_2212"),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0207_uczelnia_analiza_view")
        )
    ]
