# Generated by Django 3.0.11 on 2021-04-25 23:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0261_auto_20210426_0124"),
    ]

    operations = [
        migrations.AddField(
            model_name="bppuser",
            name="pbn_token",
            field=models.CharField(blank=True, max_length=128, null=True),
        ),
    ]
