# Generated by Django 3.0.11 on 2021-02-28 18:16

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("import_pracownikow", "0002_importpracownikowrow"),
    ]

    operations = [
        migrations.AddField(
            model_name="importpracownikowrow",
            name="integracja_mozliwa",
            field=models.NullBooleanField(),
        ),
        migrations.AlterField(
            model_name="importpracownikowrow",
            name="parent",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="row_set",
                to="import_pracownikow.ImportPracownikow",
            ),
        ),
    ]
