# Generated by Django 3.2.14 on 2022-07-08 11:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0324_django32"),
    ]

    operations = [
        migrations.AlterField(
            model_name="autor_jednostka",
            name="podstawowe_miejsce_pracy",
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="patent",
            name="wdrozenie",
            field=models.BooleanField(
                blank=True, default=None, null=True, verbose_name="Wdrożenie"
            ),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="opl_pub_other",
            field=models.BooleanField(
                blank=True,
                default=None,
                null=True,
                verbose_name="Inne środki finansowe",
            ),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="opl_pub_other",
            field=models.BooleanField(
                blank=True,
                default=None,
                null=True,
                verbose_name="Inne środki finansowe",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_other",
            field=models.BooleanField(
                blank=True,
                default=None,
                null=True,
                verbose_name="Inne środki finansowe",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_other",
            field=models.BooleanField(
                blank=True,
                default=None,
                null=True,
                verbose_name="Inne środki finansowe",
            ),
        ),
    ]
