<script type="text/javascript">
    (function ($) {
        $(document).ready(function () {
            var i = $("#id_pbn_uid");

            $("<span style=padding-left:5px;></span><input id='id_doi_pbn_get' type='button' value='Pobierz po DOI'/>").insertAfter(i);

            var doi_button = $("#id_doi_pbn_get");
            var orig = doi_button.val();

            doi_button.click(function () {
                var t = $("#id_doi").val();
                var rok = $("#id_rok").val();

                if (!t || !rok) {
                    alert("Aby wykonać zapytanie, potrzebna jest wartość w polu 'DOI' oraz 'Rok'.");
                    return;
                }

                doi_button.val("Czekaj...");
                doi_button.attr('disabled', true);

                $.ajax({
                    type: "POST",
                    url: "{% url "bpp:api_get_pbn_by_doi" %}",
                    data: {t: t, rok: rok, tytul: $("#id_tytul_oryginalny").val()},
                    error: function (request, status, error) {
                        alert('Wystąpił błąd (' + status + ', ' + error + '). Najpewniej może być on związany z ' +
                            'problemem połączenia z bazą PBN. Spróbuj za chwilę jeszcze raz.');

                        doi_button.val("Spróbuj jeszcze raz!");
                        doi_button.attr('disabled', false);

                        return;
                    },
                    success: function (data, text) {
                        var found = false;

                        doi_button.attr('disabled', false);

                        if (data.error) {
                            alert("Błąd z serwera: " + data.error + "\r\n\r\nWyszukiwanie odbywa się " +
                                "po wartości z pola 'DOI'.");

                            doi_button.val("Pobierz po DOI");
                            return;
                        }

                        doi_button.val("Pobrano!");

                        $("#id_pbn_uid").select2("open");
                        $("input.select2-search__field").val(data.id).trigger("input");
                    }
                });

            });


        });
    }(django.jQuery));
</script>
