# Generated by Django 3.2.14 on 2022-07-07 22:32

import django.core.serializers.json
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("import_dyscyplin", "0019_drop_pesel_md5"),
    ]

    operations = [
        migrations.AlterField(
            model_name="import_dyscyplin_row",
            name="original",
            field=models.JSONField(
                encoder=django.core.serializers.json.DjangoJSONEncoder
            ),
        ),
    ]
