# Generated by Django 3.0.14 on 2021-09-05 18:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0291_kod_dyscypliny_field"),
    ]

    operations = [
        migrations.AddField(
            model_name="patent_autor",
            name="przypieta",
            field=models.BooleanField(
                db_index=True,
                default=True,
                help_text='Możesz odznaczyć, żeby "odpiąć" dyscyplinę od tego autora. Dyscyplina "odpięta" nie będzie\n        wykazywana do PBN, ale będzie pojawiała się np. w raportach i innych zestawieniach. ',
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle_autor",
            name="przypieta",
            field=models.BooleanField(
                db_index=True,
                default=True,
                help_text='Możesz odznaczyć, żeby "odpiąć" dyscyplinę od tego autora. Dyscyplina "odpięta" nie będzie\n        wykazywana do PBN, ale będzie pojawiała się np. w raportach i innych zestawieniach. ',
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte_autor",
            name="przypieta",
            field=models.BooleanField(
                db_index=True,
                default=True,
                help_text='Możesz odznaczyć, żeby "odpiąć" dyscyplinę od tego autora. Dyscyplina "odpięta" nie będzie\n        wykazywana do PBN, ale będzie pojawiała się np. w raportach i innych zestawieniach. ',
            ),
        ),
    ]
