# Generated by Django 3.0.7 on 2020-08-06 06:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0215_auto_20200806_0146"),
        ("bpp", "0220_auto_20200728_0011"),
    ]

    operations = []
