# Generated by Django 3.2.14 on 2022-07-07 22:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("import_dbf", "0002_auto_20200518_0056"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="b_b",
            options={"managed": False, "ordering": ("idt__tytul_or_s", "lp")},
        ),
        migrations.AlterField(
            model_name="bib_desc",
            name="value",
            field=models.JSONField(),
        ),
    ]
