# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src',
 'bpp': 'src/bpp',
 'bpp.admin': 'src/bpp/admin',
 'bpp.admin.xlsx_export': 'src/bpp/admin/xlsx_export',
 'bpp.context_processors': 'src/bpp/context_processors',
 'bpp.fixtures': 'src/bpp/fixtures',
 'bpp.forms': 'src/bpp/forms',
 'bpp.imports': 'src/bpp/imports',
 'bpp.imports.uml': 'src/bpp/imports/uml',
 'bpp.management': 'src/bpp/management',
 'bpp.management.commands': 'src/bpp/management/commands',
 'bpp.migrations': 'src/bpp/migrations',
 'bpp.models': 'src/bpp/models',
 'bpp.models.sloty': 'src/bpp/models/sloty',
 'bpp.multiseek_registry': 'src/bpp/multiseek_registry',
 'bpp.reports': 'src/bpp/reports',
 'bpp.templatetags': 'src/bpp/templatetags',
 'bpp.tests': 'src/bpp/tests',
 'bpp.tests.test_admin': 'src/bpp/tests/test_admin',
 'bpp.tests.test_api': 'src/bpp/tests/test_api',
 'bpp.tests.test_models': 'src/bpp/tests/test_models',
 'bpp.tests.test_models.test_abstract': 'src/bpp/tests/test_models/test_abstract',
 'bpp.tests.test_models.test_sloty': 'src/bpp/tests/test_models/test_sloty',
 'bpp.tests.test_models.test_struktura': 'src/bpp/tests/test_models/test_struktura',
 'bpp.tests.test_multiseek': 'src/bpp/tests/test_multiseek',
 'bpp.tests.test_selenium': 'src/bpp/tests/test_selenium',
 'bpp.tests.test_selenium.test_admin': 'src/bpp/tests/test_selenium/test_admin',
 'bpp.tests.test_views': 'src/bpp/tests/test_views',
 'bpp.tests.test_views.test_browse': 'src/bpp/tests/test_views/test_browse',
 'bpp.tests.tests_legacy': 'src/bpp/tests/tests_legacy',
 'bpp.tests.tests_legacy.test_reports': 'src/bpp/tests/tests_legacy/test_reports',
 'bpp.tests.tests_legacy.test_views': 'src/bpp/tests/tests_legacy/test_views',
 'bpp.views': 'src/bpp/views',
 'bpp.views.api': 'src/bpp/views/api',
 'bpp.views.autocomplete': 'src/bpp/views/autocomplete',
 'bpp.views.raporty': 'src/bpp/views/raporty',
 'celeryui': 'src/celeryui',
 'celeryui.migrations': 'src/celeryui/migrations',
 'create_test_db': 'src/create_test_db',
 'create_test_db.management': 'src/create_test_db/management',
 'create_test_db.management.commands': 'src/create_test_db/management/commands',
 'create_test_db.migrations': 'src/create_test_db/migrations',
 'crossref_bpp': 'src/crossref_bpp',
 'crossref_bpp.migrations': 'src/crossref_bpp/migrations',
 'crossref_bpp.tests': 'src/crossref_bpp/tests',
 'django_bpp': 'src/django_bpp',
 'django_bpp.settings': 'src/django_bpp/settings',
 'django_bpp.staticroot': 'src/django_bpp/staticroot',
 'django_bpp.staticroot.notifications': 'src/django_bpp/staticroot/notifications',
 'django_bpp.staticroot.notifications.js': 'src/django_bpp/staticroot/notifications/js',
 'django_bpp.staticroot.notifications.js.tests': 'src/django_bpp/staticroot/notifications/js/tests',
 'dynamic_columns': 'src/dynamic_columns',
 'dynamic_columns.migrations': 'src/dynamic_columns/migrations',
 'ewaluacja2021': 'src/ewaluacja2021',
 'ewaluacja2021.core': 'src/ewaluacja2021/core',
 'ewaluacja2021.management': 'src/ewaluacja2021/management',
 'ewaluacja2021.management.commands': 'src/ewaluacja2021/management/commands',
 'ewaluacja2021.migrations': 'src/ewaluacja2021/migrations',
 'ewaluacja2021.tests': 'src/ewaluacja2021/tests',
 'ewaluacja2021.tests.test_core': 'src/ewaluacja2021/tests/test_core',
 'fixtures': 'src/fixtures',
 'formdefaults': 'src/formdefaults',
 'formdefaults.migrations': 'src/formdefaults/migrations',
 'formdefaults.tests': 'src/formdefaults/tests',
 'import_common': 'src/import_common',
 'import_common.tests': 'src/import_common/tests',
 'import_dbf': 'src/import_dbf',
 'import_dbf.management': 'src/import_dbf/management',
 'import_dbf.management.commands': 'src/import_dbf/management/commands',
 'import_dbf.migrations': 'src/import_dbf/migrations',
 'import_dbf.tests': 'src/import_dbf/tests',
 'import_dyscyplin': 'src/import_dyscyplin',
 'import_dyscyplin.management.commands': 'src/import_dyscyplin/management/commands',
 'import_dyscyplin.migrations': 'src/import_dyscyplin/migrations',
 'import_dyscyplin.tests': 'src/import_dyscyplin/tests',
 'import_list_if': 'src/import_list_if',
 'import_list_if.migrations': 'src/import_list_if/migrations',
 'import_list_if.tests': 'src/import_list_if/tests',
 'import_pracownikow': 'src/import_pracownikow',
 'import_pracownikow.migrations': 'src/import_pracownikow/migrations',
 'import_pracownikow.tests': 'src/import_pracownikow/tests',
 'import_pracownikow.tests.test_models': 'src/import_pracownikow/tests/test_models',
 'integrator2': 'src/integrator2',
 'integrator2.migrations': 'src/integrator2/migrations',
 'integrator2.models': 'src/integrator2/models',
 'integrator2.tests': 'src/integrator2/tests',
 'long_running': 'src/long_running',
 'long_running.migrations': 'src/long_running/migrations',
 'long_running.tests': 'src/long_running/tests',
 'miniblog': 'src/miniblog',
 'miniblog.migrations': 'src/miniblog/migrations',
 'notifications': 'src/notifications',
 'notifications.management': 'src/notifications/management',
 'notifications.management.commands': 'src/notifications/management/commands',
 'notifications.migrations': 'src/notifications/migrations',
 'notifications.static': 'src/notifications/static',
 'notifications.static.notifications': 'src/notifications/static/notifications',
 'notifications.static.notifications.js': 'src/notifications/static/notifications/js',
 'notifications.static.notifications.js.tests': 'src/notifications/static/notifications/js/tests',
 'notifications.templatetags': 'src/notifications/templatetags',
 'notifications.tests': 'src/notifications/tests',
 'nowe_raporty': 'src/nowe_raporty',
 'nowe_raporty.tests': 'src/nowe_raporty/tests',
 'pbn_api': 'src/pbn_api',
 'pbn_api.adapters': 'src/pbn_api/adapters',
 'pbn_api.admin': 'src/pbn_api/admin',
 'pbn_api.conf': 'src/pbn_api/conf',
 'pbn_api.integrator': 'src/pbn_api/integrator',
 'pbn_api.management': 'src/pbn_api/management',
 'pbn_api.management.commands': 'src/pbn_api/management/commands',
 'pbn_api.migrations': 'src/pbn_api/migrations',
 'pbn_api.models': 'src/pbn_api/models',
 'pbn_api.tests': 'src/pbn_api/tests',
 'raport_slotow': 'src/raport_slotow',
 'raport_slotow.migrations': 'src/raport_slotow/migrations',
 'raport_slotow.models': 'src/raport_slotow/models',
 'raport_slotow.tests': 'src/raport_slotow/tests',
 'raport_slotow.tests.test_raport_slotow_autor': 'src/raport_slotow/tests/test_raport_slotow_autor',
 'raport_slotow.tests.test_views': 'src/raport_slotow/tests/test_views',
 'raport_slotow.tests.tests_models': 'src/raport_slotow/tests/tests_models',
 'raport_slotow.views': 'src/raport_slotow/views',
 'rozbieznosci_dyscyplin': 'src/rozbieznosci_dyscyplin',
 'rozbieznosci_dyscyplin.migrations': 'src/rozbieznosci_dyscyplin/migrations',
 'rozbieznosci_if': 'src/rozbieznosci_if',
 'rozbieznosci_if.migrations': 'src/rozbieznosci_if/migrations',
 'tee': 'src/tee',
 'tee.management': 'src/tee/management',
 'tee.management.commands': 'src/tee/management/commands',
 'tee.migrations': 'src/tee/migrations',
 'test_bpp': 'src/test_bpp',
 'test_bpp.migrations': 'src/test_bpp/migrations',
 'zglos_publikacje': 'src/zglos_publikacje',
 'zglos_publikacje.admin': 'src/zglos_publikacje/admin',
 'zglos_publikacje.migrations': 'src/zglos_publikacje/migrations',
 'zglos_publikacje.tests': 'src/zglos_publikacje/tests',
 'zglos_publikacje.tests.test_admin': 'src/zglos_publikacje/tests/test_admin'}

packages = \
['api_v1',
 'api_v1.serializers',
 'api_v1.tests',
 'api_v1.viewsets',
 'bpp',
 'bpp.admin',
 'bpp.admin.xlsx_export',
 'bpp.context_processors',
 'bpp.fixtures',
 'bpp.forms',
 'bpp.imports',
 'bpp.imports.uml',
 'bpp.management',
 'bpp.management.commands',
 'bpp.migrations',
 'bpp.models',
 'bpp.models.sloty',
 'bpp.multiseek_registry',
 'bpp.reports',
 'bpp.templatetags',
 'bpp.tests',
 'bpp.tests.test_admin',
 'bpp.tests.test_api',
 'bpp.tests.test_models',
 'bpp.tests.test_models.test_abstract',
 'bpp.tests.test_models.test_sloty',
 'bpp.tests.test_models.test_struktura',
 'bpp.tests.test_multiseek',
 'bpp.tests.test_selenium',
 'bpp.tests.test_selenium.test_admin',
 'bpp.tests.test_views',
 'bpp.tests.test_views.test_browse',
 'bpp.tests.tests_legacy',
 'bpp.tests.tests_legacy.test_reports',
 'bpp.tests.tests_legacy.test_views',
 'bpp.views',
 'bpp.views.api',
 'bpp.views.autocomplete',
 'bpp.views.raporty',
 'celeryui',
 'celeryui.migrations',
 'create_test_db',
 'create_test_db.management',
 'create_test_db.management.commands',
 'create_test_db.migrations',
 'crossref_bpp',
 'crossref_bpp.migrations',
 'crossref_bpp.tests',
 'django_bpp',
 'django_bpp.settings',
 'django_bpp.staticroot',
 'django_bpp.staticroot.notifications',
 'django_bpp.staticroot.notifications.js',
 'django_bpp.staticroot.notifications.js.tests',
 'dynamic_columns',
 'dynamic_columns.migrations',
 'ewaluacja2021',
 'ewaluacja2021.core',
 'ewaluacja2021.management',
 'ewaluacja2021.management.commands',
 'ewaluacja2021.migrations',
 'ewaluacja2021.tests',
 'ewaluacja2021.tests.test_core',
 'fixtures',
 'formdefaults',
 'formdefaults.migrations',
 'formdefaults.tests',
 'import_common',
 'import_common.tests',
 'import_dbf',
 'import_dbf.management',
 'import_dbf.management.commands',
 'import_dbf.migrations',
 'import_dbf.tests',
 'import_dyscyplin',
 'import_dyscyplin.management.commands',
 'import_dyscyplin.migrations',
 'import_dyscyplin.tests',
 'import_list_if',
 'import_list_if.migrations',
 'import_list_if.tests',
 'import_pracownikow',
 'import_pracownikow.migrations',
 'import_pracownikow.tests',
 'import_pracownikow.tests.test_models',
 'integrator2',
 'integrator2.migrations',
 'integrator2.models',
 'integrator2.tests',
 'long_running',
 'long_running.migrations',
 'long_running.tests',
 'miniblog',
 'miniblog.migrations',
 'notifications',
 'notifications.management',
 'notifications.management.commands',
 'notifications.migrations',
 'notifications.static',
 'notifications.static.notifications',
 'notifications.static.notifications.js',
 'notifications.static.notifications.js.tests',
 'notifications.templatetags',
 'notifications.tests',
 'nowe_raporty',
 'nowe_raporty.tests',
 'pbn_api',
 'pbn_api.adapters',
 'pbn_api.admin',
 'pbn_api.conf',
 'pbn_api.integrator',
 'pbn_api.management',
 'pbn_api.management.commands',
 'pbn_api.migrations',
 'pbn_api.models',
 'pbn_api.tests',
 'raport_slotow',
 'raport_slotow.migrations',
 'raport_slotow.models',
 'raport_slotow.tests',
 'raport_slotow.tests.test_raport_slotow_autor',
 'raport_slotow.tests.test_views',
 'raport_slotow.tests.tests_models',
 'raport_slotow.views',
 'rozbieznosci_dyscyplin',
 'rozbieznosci_dyscyplin.migrations',
 'rozbieznosci_if',
 'rozbieznosci_if.migrations',
 'tee',
 'tee.management',
 'tee.management.commands',
 'tee.migrations',
 'test_bpp',
 'test_bpp.migrations',
 'zglos_publikacje',
 'zglos_publikacje.admin',
 'zglos_publikacje.migrations',
 'zglos_publikacje.tests',
 'zglos_publikacje.tests.test_admin']

package_data = \
{'': ['*'],
 'bpp': ['static/admin/js/*',
         'static/admin/js/vendor/jquery/*',
         'static/adminsortable2/js/*',
         'static/autocomplete_light/i18n/*',
         'static/bpp/css/*',
         'static/bpp/flick/*',
         'static/bpp/flick/images/*',
         'static/bpp/images/*',
         'static/bpp/js/*',
         'static/bpp/svg/*',
         'static/bpp/wav/*',
         'static/grappelli/jquery/i18n/*',
         'static/scss/_settings.scss',
         'static/scss/_settings.scss',
         'static/scss/_settings.scss',
         'static/scss/_settings.scss',
         'static/scss/_settings.scss',
         'static/scss/_settings.scss',
         'static/scss/_settings.scss',
         'static/scss/_settings.scss',
         'static/scss/_settings_green.scss',
         'static/scss/_settings_green.scss',
         'static/scss/_settings_green.scss',
         'static/scss/_settings_green.scss',
         'static/scss/_settings_green.scss',
         'static/scss/_settings_green.scss',
         'static/scss/_settings_green.scss',
         'static/scss/_settings_green.scss',
         'static/scss/_settings_orange.scss',
         'static/scss/_settings_orange.scss',
         'static/scss/_settings_orange.scss',
         'static/scss/_settings_orange.scss',
         'static/scss/_settings_orange.scss',
         'static/scss/_settings_orange.scss',
         'static/scss/_settings_orange.scss',
         'static/scss/_settings_orange.scss',
         'static/scss/app-blue.scss',
         'static/scss/app-blue.scss',
         'static/scss/app-blue.scss',
         'static/scss/app-blue.scss',
         'static/scss/app-blue.scss',
         'static/scss/app-blue.scss',
         'static/scss/app-blue.scss',
         'static/scss/app-blue.scss',
         'static/scss/app-green.scss',
         'static/scss/app-green.scss',
         'static/scss/app-green.scss',
         'static/scss/app-green.scss',
         'static/scss/app-green.scss',
         'static/scss/app-green.scss',
         'static/scss/app-green.scss',
         'static/scss/app-green.scss',
         'static/scss/app-orange.scss',
         'static/scss/app-orange.scss',
         'static/scss/app-orange.scss',
         'static/scss/app-orange.scss',
         'static/scss/app-orange.scss',
         'static/scss/app-orange.scss',
         'static/scss/app-orange.scss',
         'static/scss/app-orange.scss',
         'static/scss/checkbox.scss',
         'static/scss/checkbox.scss',
         'static/scss/checkbox.scss',
         'static/scss/checkbox.scss',
         'static/scss/checkbox.scss',
         'static/scss/checkbox.scss',
         'static/scss/checkbox.scss',
         'static/scss/checkbox.scss',
         'static/scss/common.scss',
         'static/scss/common.scss',
         'static/scss/common.scss',
         'static/scss/common.scss',
         'static/scss/common.scss',
         'static/scss/common.scss',
         'static/scss/common.scss',
         'static/scss/common.scss',
         'templates/*',
         'templates/admin/*',
         'templates/autocompletes/*',
         'templates/browse/*',
         'templates/raporty/*',
         'templates/raporty/raport_jednostek_autorow_2012/*',
         'templates/raporty/raport_komisji_centralnej/*',
         'templates/raporty/strona_raportow/*'],
 'bpp.tests.test_admin': ['cassettes/test_crossref_api_helpers/*',
                          'cassettes/test_crossref_api_sync/*'],
 'celeryui': ['locale/pl/LC_MESSAGES/*'],
 'crossref_bpp.tests': ['cassettes/test_forms/*', 'cassettes/test_views/*'],
 'django_bpp': ['templates/*',
                'templates/admin/*',
                'templates/admin/bpp/autor/*',
                'templates/admin/bpp/bppuser/*',
                'templates/admin/bpp/patent/*',
                'templates/admin/bpp/szablondlaopisubibliograficznego/*',
                'templates/admin/bpp/wydawca/*',
                'templates/admin/bpp/wydawnictwo_ciagle/*',
                'templates/admin/bpp/wydawnictwo_ciagle_autor/*',
                'templates/admin/bpp/wydawnictwo_zwarte/*',
                'templates/admin/bpp/wydawnictwo_zwarte_autor/*',
                'templates/admin/bpp/zrodlo/*',
                'templates/admin/dbtemplates/template/*',
                'templates/adminsortable2/*',
                'templates/cookielaw/*',
                'templates/multiseek/*',
                'templates/pagination/*',
                'templates/permissions_widget/*',
                'templates/registration/*',
                'templates/rest_framework/*'],
 'django_bpp.staticroot': ['CACHE-202210.1089/*',
                           'CACHE-202210.1089/css/*',
                           'CACHE-202210.1089/js/*',
                           'admin/css/*',
                           'admin/css/vendor/select2/*',
                           'admin/fonts/*',
                           'admin/img/*',
                           'admin/img/gis/*',
                           'admin/js/*',
                           'admin/js/admin/*',
                           'admin/js/vendor/jquery/*',
                           'admin/js/vendor/select2/*',
                           'admin/js/vendor/select2/i18n/*',
                           'admin/js/vendor/xregexp/*',
                           'admin_tools/css/*',
                           'admin_tools/css/jquery/*',
                           'admin_tools/css/jquery/images/*',
                           'admin_tools/images/*',
                           'admin_tools/js/*',
                           'admin_tools/js/jquery/*',
                           'adminsortable2/css/*',
                           'adminsortable2/icons/*',
                           'adminsortable2/js/*',
                           'adminsortable2/js/libs/*',
                           'adminsortable2/js/plugins/*',
                           'autocomplete_light/*',
                           'autocomplete_light/i18n/*',
                           'bpp/css/*',
                           'bpp/flick/*',
                           'bpp/flick/images/*',
                           'bpp/images/*',
                           'bpp/js/*',
                           'bpp/svg/*',
                           'bpp/wav/*',
                           'cookielaw/css/*',
                           'cookielaw/img/*',
                           'cookielaw/js/*',
                           'css/*',
                           'datatables.net-zf/css/*',
                           'datatables.net-zf/js/*',
                           'datatables.net/js/*',
                           'dbtemplates/css/*',
                           'dbtemplates/js/*',
                           'django_extensions/css/*',
                           'django_extensions/img/*',
                           'django_extensions/js/*',
                           'django_tables2/*',
                           'django_tables2/themes/paleblue/css/*',
                           'django_tables2/themes/paleblue/img/*',
                           'djangoql/css/*',
                           'djangoql/img/*',
                           'djangoql/js/*',
                           'ewaluacja2021/xlsx/*',
                           'foundation-datepicker/css/*',
                           'foundation-datepicker/foundation/fonts/*',
                           'foundation-datepicker/foundation/fonts/svgs/*',
                           'foundation-datepicker/js/*',
                           'foundation-datepicker/js/locales/*',
                           'foundation-sites/dist/css/*',
                           'foundation-sites/dist/js/*',
                           'grappelli/images/*',
                           'grappelli/images/backgrounds/*',
                           'grappelli/images/icons-small/*',
                           'grappelli/images/icons/*',
                           'grappelli/img/admin/*',
                           'grappelli/jquery/*',
                           'grappelli/jquery/i18n/*',
                           'grappelli/jquery/ui/*',
                           'grappelli/jquery/ui/external/jquery/*',
                           'grappelli/jquery/ui/images/*',
                           'grappelli/js/*',
                           'grappelli/stylesheets/*',
                           'grappelli/stylesheets/mueller/*',
                           'grappelli/stylesheets/mueller/grid/*',
                           'grappelli/stylesheets/partials/custom/*',
                           'grappelli/tinymce_setup/*',
                           'import_dyscyplin/xlsx/*',
                           'import_export/*',
                           'import_list_if/*',
                           'import_pracownikow/*',
                           'jinplace/js/*',
                           'jquery.cookie/*',
                           'jquery/dist/*',
                           'jqueryui/*',
                           'js/*',
                           'js/crispy_forms_foundation/*',
                           'kbw-keypad/dist/*',
                           'kbw-keypad/dist/css/*',
                           'kbw-keypad/dist/img/*',
                           'kbw-keypad/dist/js/*',
                           'mptt/*',
                           'multiseek/css/*',
                           'multiseek/js/*',
                           'rest_framework/css/*',
                           'rest_framework/fonts/*',
                           'rest_framework/img/*',
                           'rest_framework/js/*',
                           'scss/*',
                           'select2-foundation_theme/dist/*',
                           'select2/dist/css/*',
                           'select2/dist/js/*',
                           'select2/dist/js/i18n/*',
                           'session_security/*',
                           'vendor/select2/dist/css/*',
                           'what-input/dist/*'],
 'dynamic_columns': ['locale/pl/LC_MESSAGES/django.po'],
 'ewaluacja2021': ['static/ewaluacja2021/xlsx/*', 'templates/ewaluacja2021/*'],
 'import_dbf': ['sql/*'],
 'import_dyscyplin': ['static/import_dyscyplin/xlsx/*',
                      'templates/import_dyscyplin/*'],
 'import_list_if': ['static/import_list_if/*', 'templates/import_list_if/*'],
 'import_pracownikow': ['static/import_pracownikow/*',
                        'templates/import_pracownikow/*'],
 'integrator2': ['templates/*', 'templates/integrator2/*'],
 'integrator2.tests': ['xls/*'],
 'long_running': ['templates/long_running/*'],
 'miniblog': ['locale/pl/LC_MESSAGES/django.po'],
 'nowe_raporty': ['fixtures/*', 'templates/nowe_raporty/*'],
 'pbn_api': ['templates/admin/pbn_api/institution/*',
             'templates/admin/pbn_api/journal/*',
             'templates/admin/pbn_api/oswiadczenieinstytucji/*',
             'templates/admin/pbn_api/publication/*',
             'templates/admin/pbn_api/publikacjainstytucji/*',
             'templates/admin/pbn_api/publisher/*',
             'templates/admin/pbn_api/scientist/*',
             'templates/admin/pbn_api/sentdata/*'],
 'raport_slotow': ['templates/raport_slotow/*'],
 'rozbieznosci_dyscyplin': ['templates/admin/rozbieznosci_dyscyplin/rozbieznosciview/*',
                            'templates/admin/rozbieznosci_dyscyplin/rozbieznoscizrodelview/*',
                            'templates/rozbieznosci_dyscyplin/*'],
 'rozbieznosci_if': ['templates/rozbieznosci_if/*'],
 'zglos_publikacje': ['templates/admin/zglos_publikacje/zgloszenie_publikacji/*',
                      'templates/templated_email/*',
                      'templates/zglos_publikacje/*']}

install_requires = \
['Django>=3.2,<3.3',
 'MOAI-iplweb==2.0.0',
 'Markdown==3.2.1',
 'Pillow==9.2.0',
 'Unidecode==0.4.20',
 'arrow==1.2.1',
 'bleach>=3.3.0',
 'celery[redis]==5.2.7',
 'channels-redis==3.4.0',
 'channels==3.0.5',
 'crispy-forms-foundation==0.8.0',
 'crossrefapi>=1.5.0,<2.0.0',
 'cssmin==0.2.0',
 'dbfread>=2.0.7,<3.0.0',
 'dj-pagination==2.4.0',
 'django-admin-sortable2==1.0',
 'django-admin-tools==0.9.0',
 'django-auth-ldap>=4.1.0,<5.0.0',
 'django-autocomplete-light==3.9.4',
 'django-autoslug==1.9.8',
 'django-braces>=1.15.0,<2.0.0',
 'django-cacheops==6.1',
 'django-celery-email>=3.0.0,<4.0.0',
 'django-celery-results==2.4.0',
 'django-classy-tags==1.0.0',
 'django-columns==0.1.0',
 'django-compressor==2.4',
 'django-cookie-law==2.0.3',
 'django-crispy-forms==1.9.0',
 'django-dbtemplates-iplweb==4.1.0',
 'django-denorm-iplweb==1.1.0',
 'django-dirtyfields==1.3.1',
 'django-easy-audit>=1.3.3,<2.0.0',
 'django-environ>=0.9.0,<0.10.0',
 'django-extensions==3.1.3',
 'django-favicon-plus==0.0.8',
 'django-filter==21.1',
 'django-flexible-reports>0.2.9',
 'django-formtools>=2.3,<3.0',
 'django-fsm==2.8.0',
 'django-grappelli==2.15.5',
 'django-group-by==0.3.1',
 'django-htmlmin==0.11.0',
 'django-import-export==2.5.0',
 'django-loginas==0.3.8',
 'django-messages-extends==0.6.2',
 'django-model-utils==4.0.0',
 'django-mptt==0.13.4',
 'django-multiseek==0.9.47',
 'django-password-policies-iplweb==0.8.4',
 'django-permissions-widget==1.5.2',
 'django-querysetsequence==0.12',
 'django-redis-cache==2.1.1',
 'django-reversion==4.0.0',
 'django-robots==4.0',
 'django-sendfile==0.3.11',
 'django-session-security-iplweb==2.6.6',
 'django-static-sitemaps>=4.7.0,<5.0.0',
 'django-tables2==2.3.1',
 'django-taggit-serializer==0.1.7',
 'django-taggit==3.0.0',
 'django-templated-email>=3.0.0,<4.0.0',
 'django-weasyprint>=2.1.0,<3.0.0',
 'django-webmaster-verification==0.3.0',
 'djangoql==0.15.3',
 'djangorestframework==3.11.2',
 'olefile==0.44',
 'openpyxl==3.0.10',
 'pathspec>=0.9.0,<0.10.0',
 'progressbar2>=4.0.0,<5.0.0',
 'psycopg2==2.8.6',
 'pygad==2.16.1',
 'pymed-iplweb==0.8.10',
 'pyoai==2.5.0',
 'pypandoc==1.5',
 'requests-oauthlib==1.3.0',
 'requests==2.26.0',
 'rjsmin==1.1.0',
 'sentry-sdk==1.9.2',
 'simplejson==3.17.5',
 'tablib==1.1.0',
 'uvicorn[standard]==0.18.2',
 'weasyprint==55.0',
 'wosclient==0.1.5',
 'xlrd==2.0.1',
 'zope.component==4.6.2',
 'zope.interface==5.1.0']

entry_points = \
{'console_scripts': ['bpp-manage.py = django_bpp.manage_command:entry_point']}

setup_kwargs = {
    'name': 'bpp-iplweb',
    'version': '202210.1089',
    'description': '',
    'long_description': 'None',
    'author': 'Michał Pasternak',
    'author_email': 'michal.dtz@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<3.11',
}


setup(**setup_kwargs)
