# Generated by Django 3.0.14 on 2022-02-27 19:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0310_fix_refresh_cache_deadlocks"),
    ]

    operations = [
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="kwartyl_w_scopus",
            field=models.IntegerField(
                blank=True,
                choices=[(None, "brak"), (1, "Q1"), (2, "Q2"), (3, "Q3"), (4, "Q4")],
                default=None,
                null=True,
                verbose_name="Kwartyl w SCOPUS",
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="kwartyl_w_wos",
            field=models.IntegerField(
                blank=True,
                choices=[(None, "brak"), (1, "Q1"), (2, "Q2"), (3, "Q3"), (4, "Q4")],
                default=None,
                null=True,
                verbose_name="Kwartyl w WoS",
            ),
        ),
    ]
