<div class="row"><div class="large-4 columns">
    {% for typ in typy %}
        <input type="checkbox" name="typ" id="typ_{{ typ }}"
               value="{{ typ }}">
        <label for="typ_{{ typ }}">
            {{ typ }}</label>
        <br/>
    {% endfor %}
</div>
</div>