# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-06-12 22:22
from __future__ import unicode_literals

import bpp.models.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0137_auto_20180613_0015'),
    ]

    operations = [
        migrations.AddField(
            model_name='uczelnia',
            name='pokazuj_liczbe_cytowan_w_rankingu',
            field=bpp.models.fields.OpcjaWyswietlaniaField(choices=[('always', 'zawsze'), ('logged-in', 'tylko dla zalogowanych'), ('never', 'nigdy')], default='always', max_length=50, verbose_name='Pokazuj liczbę cytowań w rankingu'),
        ),
    ]
