{% extends "base.html" %}

{% block extratitle %}
    {{ title }}
{% endblock %}

{% block breadcrumbs %}
    {{ block.super }}
    <li><a href="{% url form_link %}">{{ form_title }}</a></li>
    <li class="current">{{ title }} &nbsp;</li>
{% endblock %}

{% block content %}
    {% if not report %}
        Nie znaleziono definicji wybranego raportu w bazie danych.
        Skontaktuj się z administratorem systemu.
    {% else %}
        {% if request.user.is_staff %}
            <div class="callout hide-for-print">
                <a target="_blank"
                   href="{% url "admin:flexible_reports_report_change" report.pk %}"
                >
                    otwórz do edycji
                </a>
            </div>
        {% endif %}

        {% load flexible_reports_tags %}
        {% flexible report %}
    {% endif %}

{% endblock %}