{% extends "admin/change_form.html" %}

{% block object-tools-items %}
    {% if original.publicationId_id %}
        <li><a target="_blank" href="{{ original.publicationId.link_do_pbn }}">Zobacz publikacje w PBN</a></li>
    {% endif %}
    {% if original.insPersonId_id %}
        <li><a target="_blank" href="{{ original.insPersonId.link_do_pbn }}">Zobacz autora w PBN</a></li>
        {% if original.insPersonId.rekord_w_bpp %}
            <li><a target="_blank" href="{{ original.insPersonId.rekord_w_bpp.get_absolute_url }}">Zobacz autora w
                BPP</a></li>
        {% else %}
            <li><a href="#" class="disabled">Brak dopasowania autora w BPP</a></li>

        {% endif %}
    {% endif %}
    {% if original.publicationId.rekord_w_bpp %}
        <li><a target="_blank" href="{{ original.publicationId.rekord_w_bpp.original.get_absolute_url }}">Zobacz rekord
            w BPP</a></li>
    {% else %}
        <li><a href="#" class="disabled">Brak dopasowania rekordu w BPP</a></li>
    {% endif %}
    {{ block.super }}
{% endblock %}
