# Generated by Django 3.0.14 on 2021-10-11 08:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0305_merge_20211010_2323"),
    ]

    operations = [
        migrations.DeleteModel(
            name="Ewaluacja2021LiczbaNDlaUczelni",
        ),
    ]
