# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-24 00:19
from __future__ import unicode_literals

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):
    dependencies = [
        ('bpp', '0104_nowe_sumy_view'),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0105_rekord_z_konferencja")),

    ]
