# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-11-25 11:03
from __future__ import unicode_literals

from decimal import Decimal

from django.db import migrations, models

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):
    dependencies = [
        ('bpp', '0150_auto_20181125_1202'),
    ]

    operations = [
        migrations.AddField(
            model_name='patent',
            name='punktacja_snip',
            field=models.DecimalField(db_index=True, decimal_places=3, default=Decimal('0.000'),
                                      help_text='CiteScore SNIP (Source Normalized Impact per Paper)', max_digits=6,
                                      verbose_name='Punktacja SNIP'),
        ),
        migrations.AddField(
            model_name='praca_doktorska',
            name='punktacja_snip',
            field=models.DecimalField(db_index=True, decimal_places=3, default=Decimal('0.000'),
                                      help_text='CiteScore SNIP (Source Normalized Impact per Paper)', max_digits=6,
                                      verbose_name='Punktacja SNIP'),
        ),
        migrations.AddField(
            model_name='praca_habilitacyjna',
            name='punktacja_snip',
            field=models.DecimalField(db_index=True, decimal_places=3, default=Decimal('0.000'),
                                      help_text='CiteScore SNIP (Source Normalized Impact per Paper)', max_digits=6,
                                      verbose_name='Punktacja SNIP'),
        ),
        migrations.AddField(
            model_name='punktacja_zrodla',
            name='punktacja_snip',
            field=models.DecimalField(db_index=True, decimal_places=3, default=Decimal('0.000'),
                                      help_text='CiteScore SNIP (Source Normalized Impact per Paper)', max_digits=6,
                                      verbose_name='Punktacja SNIP'),
        ),
        migrations.AddField(
            model_name='uczelnia',
            name='pokazuj_punktacja_snip',
            field=models.BooleanField(default=True, verbose_name='Pokazuj punktację SNIP na stronie rekordu'),
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='punktacja_snip',
            field=models.DecimalField(db_index=True, decimal_places=3, default=Decimal('0.000'),
                                      help_text='CiteScore SNIP (Source Normalized Impact per Paper)', max_digits=6,
                                      verbose_name='Punktacja SNIP'),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='punktacja_snip',
            field=models.DecimalField(db_index=True, decimal_places=3, default=Decimal('0.000'),
                                      help_text='CiteScore SNIP (Source Normalized Impact per Paper)', max_digits=6,
                                      verbose_name='Punktacja SNIP'),
        ),
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0151_snip")
        ),

    ]
