{% extends "django_tables2/table.html" %}

{% load i18n django_tables2 %}

{% block table.tfoot %}{% spaceless %}
        <tr>
            <td colspan="3">
                <table class="bez_ramki" style="width:100%;">
                    <tr>
                        <td>
                            Liczba prac: {{ table.counter }}</td>
                        <td align="center">
                            Suma punktów
                        </td>
                    </tr>
                </table>
            </td>
            <td align="right">{{ table.columns.impact_factor.footer }}</td>
            <td align="right">{{ table.columns.punkty_kbn.footer }}</td>
        </tr>
{% endspaceless %}{% endblock %}

{% block pagination %}
    {# bez paginacji - wyrzucamy całą tabelę #}
{% endblock %}
