# Generated by Django 2.2.10 on 2020-03-15 21:12

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0205_merge_20200315_2208"),
    ]

    operations = [
        migrations.CreateModel(
            name="Cache_Punktacja_Autora_Query_View",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("pkdaut", models.DecimalField(decimal_places=4, max_digits=20)),
                ("slot", models.DecimalField(decimal_places=4, max_digits=20)),
                (
                    "zapisani_autorzy_z_dyscypliny",
                    django.contrib.postgres.fields.ArrayField(
                        base_field=models.TextField(), size=None
                    ),
                ),
            ],
            options={
                "db_table": "bpp_cache_punktacja_autora_view",
                "ordering": ("autor__nazwisko", "dyscyplina__nazwa"),
                "managed": False,
            },
        ),
        migrations.AlterField(
            model_name="autor",
            name="aktualny",
            field=models.BooleanField(
                db_index=True,
                default=False,
                help_text="Jeżeli zaznaczone, pole to oznacza,\n    że autor jest aktualnie - na dziś dzień - przypisany do jakiejś jednostki w bazie danych i jego przypisanie\n    do tej jednostki nie zostało zakończone wraz z konkretną datą w\n    przeszłości.",
                verbose_name="Aktualny?",
            ),
        ),
    ]
