{% load i18n %}
{% load pagination_tags %}

{% load compress %}
{% load prace %}

{% include "multiseek/print-logo.html" %}
{% include "multiseek/title.html" %}

    {%  if paginator_count > 25000 %}
        <div style="padding-left: 4em; padding-right: 4em;">
        <p>Wynik obecnego zapytania do bazy dałby w rezultacie {{ paginator_count }} rekordów. Jest to dość duża ilość
            i szczerze mówiąc pobieranie ich wszystkich przez tą stronę WWW będzie dla Ciebie dość karkołomne. Stąd też
            wyświetlenie ich wszystkich nie wydaje się być na ten moment najlepszym pomysłem.
            </p>
            <p>
            Prosimy, postaraj się ograniczyć zapytanie do bazy danych w taki sposób, aby dawało w rezultacie maksymalnie
                do 25 tysięcy rekordów - wówczas zostaną one wyświetlone w wybranym przez Ciebie formacie w tym miejscu.</p>
        <p>Jeżeli potrzebujesz pobrać wszystkie rekordy z systemu BPP, skorzystaj z dostępu przez API. Obsługiwane
            API to <a target="_blank" href="/api/v1/">JSON-REST</a> oraz <a target="_blank" href="/bpp/oai/?verb=ListSets">protokół OAI-PMH</a>.
        </div>
    {% else %}

{% if request.user.is_anonymous %}
    {#    anonim #}
    {% if request.GET.all == "1" %}
        {% autopaginate object_list paging uczelnia.wyszukiwanie_rekordy_na_strone_anonim %}
    {% else %}
        {% autopaginate object_list paging %}
    {% endif %}
{% else %}
    {#    zalogowany #}
    {% if request.GET.all == "1" %}
        {% autopaginate object_list paging uczelnia.wyszukiwanie_rekordy_na_strone_zalogowany %}
    {% else %}
        {% autopaginate object_list paging %}
    {% endif %}

{% endif %}

{% if request.user.is_anonymous %}
    {% include "multiseek/paginator.html" with max_rows=uczelnia.wyszukiwanie_rekordy_na_strone_anonim %}
{% else %}
    {% include "multiseek/paginator.html" with max_rows=uczelnia.wyszukiwanie_rekordy_na_strone_zalogowany %}
{% endif %}

<div style="padding: 10px;">

    {% if description %}
        <div class="callout secondary {% if not uczelnia.wydruk_parametry_zapytania %}hide-for-print{% endif %}">
            <strong>Parametry
                zapytania: </strong>{{ description|default:"brak"|safe }}
        </div>
    {% endif %}

    {% if removed_ids %}
        <script type="text/javascript">
        function togglePokaz(){
            $('#rekordy-usuniete').toggle();
        }

        $(document).ready(function(){
            $("#rekordy-usuniete").hide();
        });
        </script>
        {% if not print_removed %}
            <div class="callout info hide-for-print" id="panel-removed-by-hand">
                Z zapytania usunięto ręcznie <span id="no-removed-recs">{{ removed_ids|length }}</span> rekord(ów).
                <a id="pokaz-jakie" onclick="togglePokaz()">Pokaż, jakie.</a>
                | <a onclick="return confirm('Czy na pewno dodać wszystkie ręcznie usunięte prace do wyników wyszukiwania ponownie?');" href="../reenable-removed-ids/">Kliknij tutaj, aby dodać je wszystkie do wyszukiwania z powrotem.</a>
                | <a href=".">Odśwież stronę</a>
                | <a href="?print-removed=1&all=1">Pokaż tylko rekordy usunięte ręcznie</a>
                | <a href="?print=1&print-removed=1&all=1">Wydrukuj tylko rekordy usunięte ręcznie</a>

                <div id="rekordy-usuniete">
                    <p>
                    <ul>
                        {% for elem in removed_ids %}
                            <li id="multiseek-row-{{ elem.0 }}_{{ elem.1 }}" class="multiseek-row">
                                <span class="multiseek-element" style="text-decoration: line-through">
                                {% opis_bibliograficzny_cache elem %}
                                    </span>
                                <a onclick="multiseek.removeFromResults('{{ elem.0 }}_{{ elem.1 }}')"
                                style="font-size: 8pt;">
                                    &nbsp;✅
                                </a>
                            </li>
                        {% endfor %}
                    </ul>
                    </p>
                </div>

            </div>
        {% else %}
           <div class="callout info hide-for-print" id="panel-removed-by-hand">
           <strong>Wyświetlam listę rekordów usuniętych ręcznie z zapytania. </strong><p></p>
           <a href=".">Kliknij tutaj, aby wyświetlić wszystkie rekordy.</a>
            </div>
        {% endif %}
    {% endif %}

    {% if report_type == "list" or report_type == "numer_list" or report_type == None %}
        <ol start="{{ page_obj.start_index }}">
            {% for element in object_list %}

                <li class="multiseek-row" id="multiseek-row-{{ element.js_safe_pk }}">
                    <span class="multiseek-element">
                        <a href="{% url "bpp:browse_praca" element.id.0 element.id.1 %}"
                           target="_top">
                            {{ element.opis_bibliograficzny_cache|safe }}

                        </a>

                        {% if report_type == "numer_list" %}
                            <span style="color: red;">
                    {{ element.uwagi }}
                    </span>
                        {% endif %}

                    </span>
                {% if not print_removed %}
                    <span class="multiseek-remove-from-results">
                        <a onclick="multiseek.removeFromResults('{{ element.js_safe_pk }}'); return false" style="font-size: 8pt;">
                            ❌
                        </a>
                    </span>
                {% endif %}
                </li>
            {% empty %}
                {% trans "No elements" %}
            {% endfor %}
        </ol>
    {% else %}
        <table class="kbntab">
            <tr>
                <th>Lp.</th>
                <th>Tytuł, autorzy, źródło</th>
                <th>IF</th>

                {% if report_type == "table_cytowania" or report_type == "pkt_wewn_cytowania" or report_type == "pkt_wewn_bez_cytowania" %}
                    <th>Liczba cytowań</th>
                {% endif %}

                <th>PK</th>

                {% if report_type == "pkt_wewn" or report_type == "pkt_wewn_cytowania" %}
                    <th>pkt. wewn.</th>
                {% endif %}

                {% if report_type != "pkt_wewn" and report_type != "pkt_wewn_bez" and report_type != "pkt_wewn_cytowania" and report_type != "pkt_wewn_bez_cytowania" %}
                    <th>Charakter</th>
                {% endif %}

                <th>Typ KBN/MNiSW</th>
            </tr>
            {% for element in object_list %}
                <tr>
                    <td valign="top">
                        {{ page_obj.start_index|add:forloop.counter|add:-1 }}.
                    </td>
                    <td class="multiseek-row"
                          id="multiseek-row-{{ element.js_safe_pk }}">
                    <span class="multiseek-element">
                    <a href="{% url "bpp:browse_praca" element.id.0 element.id.1 %}"
                       target="_top">
                        {{ element.opis_bibliograficzny_cache|safe }}

                    </a>
                    </span>
                        {% if not print_removed %}
                    <span class="multiseek-remove-from-results">
                        <a onclick="multiseek.removeFromResults('{{ element.js_safe_pk }}'); return false" style="font-size: 8pt;">
                            ❌
                        </a>
                    </span>
                        {% endif %}
                    </td>
                    <td>{{ element.impact_factor }}</td>
                    {% if report_type == "table_cytowania" or report_type == "pkt_wewn_cytowania" or report_type == "pkt_wewn_bez_cytowania" %}
                        <td>{{ element.liczba_cytowan }}</td>
                    {% endif %}

                    <td>{{ element.punkty_kbn }}</td>

                    {% if report_type == "pkt_wewn" or report_type == "pkt_wewn_cytowania" %}
                        <td>{{ element.punktacja_wewnetrzna }}</td>
                    {% endif %}

                {% if report_type != "pkt_wewn" and report_type != "pkt_wewn_bez" and report_type != "pkt_wewn_cytowania" and report_type != "pkt_wewn_bez_cytowania" %}
                    <td>{{ element.charakter_formalny }}</td>
                {% endif %}
                    <td>{{ element.typ_kbn }}</td>
                </tr>
            {% empty %}
                <tr>
                    <td colspan="10" style="text-align: center;">{% trans "No elements" %}
                    </td>
                </tr>
            {% endfor %}

            {% if page_obj.number == page_obj.paginator.num_pages %}
                <tfoot>
                <tr>
                    <td colspan="2">
                        Suma:
                    </td>
                    <td>
                        {{ sumy.impact_factor__sum|default_if_none:"0.00" }}
                    </td>
                    {% if report_type == "table_cytowania" or report_type == "pkt_wewn_cytowania" or report_type == "pkt_wewn_bez_cytowania" %}
                        <td>
                            {{ sumy.liczba_cytowan__sum|default_if_none:"0.00" }}
                        </td>
                    {% endif %}
                    <td>
                        {{ sumy.punkty_kbn__sum|default_if_none:"0.00" }}
                    </td>
                    {% if report_type == "pkt_wewn" or report_type == "pkt_wewn_cytowania" %}
                        <td>
                            {{ sumy.punktacja_wewnetrzna__sum|default_if_none:"0.00" }}
                        </td>
                    {% endif %}
                    <td>&nbsp;</td>
                    <td>&nbsp;</td>
                </tr>
                </tfoot>
            {% endif %}

        </table>
    {% endif %}

</div>

{% if live != "1" and paginator.num_pages > 1 %}
    {% if request.user.is_anonymous %}
        {% include "multiseek/paginator.html" with max_rows=uczelnia.wyszukiwanie_rekordy_na_strone_anonim magellan="no" suffix="_object_list" %}
    {% else %}
        {% include "multiseek/paginator.html" with max_rows=uczelnia.wyszukiwanie_rekordy_na_strone_zalogowany magellan="no" %}
    {% endif %}
{% endif %}

    {% endif %}

<script type="text/javascript">
    if (queryDict.print == "1")
        window.print();
</script>
