# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-04-16 11:13
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0128_zewnetrzne_bazy_view'),
    ]

    operations = [
        migrations.CreateModel(
            name='ZewnetrzneBazyDanychView',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('info', models.TextField()),
            ],
            options={
                'db_table': 'bpp_zewnetrzne_bazy_view',
                'managed': False,
            },
        ),
    ]
