# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-04-15 06:13
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('import_dyscyplin', '0007_auto_20180414_1917'),
    ]

    operations = [
        migrations.AddField(
            model_name='import_dyscyplin_row',
            name='imiona',
            field=models.CharField(default='', max_length=200),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='import_dyscyplin_row',
            name='nazwisko',
            field=models.CharField(default='', max_length=200),
            preserve_default=False,
        ),
    ]
